﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Web.UI.WebControls;
using AutoProofreader.Enums;

namespace AutoProofreader.UI.WebControls
{
    public class AprDropDownList: DropDownList
    {
        private string selectedValue;

        public string EnumType;
        public string EmptyListItem { get; set; }


        public override string SelectedValue
        {
            get
            {
                return base.SelectedValue;
            }
            set
            {
                selectedValue = value;
                base.SelectedValue = value;
            }
        }
        public AprDropDownList()
        {
            
        }

        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);
        }


        protected override void OnDataBound(EventArgs e)
        {
            base.OnDataBound(e);

            if (EnumType == null && !string.IsNullOrEmpty(this.EmptyListItem) && this.Items.Count == 0)
            {
                InsertListItem(0, "", EmptyListItem);
            }

        }

        protected override void EnsureDataBound()
        {
            if (EnumType != null)
            {
                if (!Page.IsPostBack)
                {
                    if (!string.IsNullOrEmpty(this.EmptyListItem))
                    {
                        InsertListItem(0, "", EmptyListItem);
                    }

                    switch (EnumType)
                    {
                        case "UserType":
                            AddListItem(UserType.Administrator.ToString(), UserType.ToString(UserType.Administrator));
                            AddListItem(UserType.Student.ToString(), UserType.ToString(UserType.Student));
                            AddListItem(UserType.Teacher.ToString(), UserType.ToString(UserType.Teacher));
                            break;
                        case "LogType":
                            AddListItem(LogType.Info.ToString(), LogType.ToString(LogType.Info));
                            AddListItem(LogType.Warning.ToString(), LogType.ToString(LogType.Warning));
                            AddListItem(LogType.Error.ToString(), LogType.ToString(LogType.Error));
                            break;
                        case "AnswersType":
                            AddListItem(AnswersType.OneCorrect.ToString(), AnswersType.ToString(AnswersType.OneCorrect));
                            AddListItem(AnswersType.MultipleCorrect.ToString(), AnswersType.ToString(AnswersType.MultipleCorrect));
                            AddListItem(AnswersType.FreeText.ToString(), AnswersType.ToString(AnswersType.FreeText));
                            break;
                        case "EvaluationType":
                            AddListItem(EvaluationType.AtoD.ToString(), EvaluationType.ToString(EvaluationType.AtoD));
                            AddListItem(EvaluationType.OneToTen.ToString(), EvaluationType.ToString(EvaluationType.OneToTen));
                            AddListItem(EvaluationType.OneToHoundred.ToString(), EvaluationType.ToString(EvaluationType.OneToHoundred));
                            break;
                    }
                }
            }

            base.EnsureDataBound();
        }
        protected override void OnDataBinding(EventArgs e)
        {
            base.OnDataBinding(e);
        }

        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);
        }

        protected override void OnPreRender(EventArgs e)
        {

            base.OnPreRender(e);
        }

        private void AddListItem(string value, string text)
        {
            this.Items.Add(new ListItem(text, value.ToString()));
        }

        private void InsertListItem(int pos, string value, string text)
        {
            this.Items.Insert(0, new ListItem(text, value.ToString()));
        }

        protected override void Render(System.Web.UI.HtmlTextWriter writer)
        {
            if (!string.IsNullOrEmpty(this.selectedValue))
            {
                this.SelectedValue = selectedValue;
            }

            base.Render(writer);
        }
    }
}
