﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using AutoProofreader.Utils;

namespace AutoProofreader.UI.WebControls
{
    [ParseChildren(true, "MenuItems"), PersistChildren(false)]
    [PersistenceMode(PersistenceMode.InnerProperty)]
    public class AprMenu: Control
    {
        private HiddenField hidSelectedIndex = new HiddenField();

        public int? SelectedIndex
        {
            get
            {
                int? queryStringIndex= TypeUtils.ToInt(this.Page.Request.QueryString["i"]);
                if (! Page.IsPostBack && queryStringIndex.HasValue)
                {
                    return queryStringIndex.Value;
                }
                else
                {
                    return TypeUtils.ToInt(hidSelectedIndex.Value);
                }
            }
            set
            {
                hidSelectedIndex.Value= value.ToString();
            }
        }

        private List<AprMenuItem> menuItems = new List<AprMenuItem>();                
        public List<AprMenuItem> MenuItems
        {
            get
            {
                return menuItems;
            }
            set 
            {
                menuItems = value;
            }
        }

        public bool ShowOnlyFirstMenuItem { get; set; }

        public AprMenu()
        { 
             ShowOnlyFirstMenuItem = false;
        }

        protected override void OnInit(EventArgs e)
        {            
            if (string.IsNullOrEmpty(this.ID))
            {
                throw new ArgumentNullException("Menu control ID can't null");
            }
          
            this.EnsureChildControls();

            base.OnInit(e);
        }

        protected override void OnLoad(EventArgs e)
        {
            hidSelectedIndex.ID = "hid" + this.ID;
            if (SelectedIndex.HasValue)
            {
                hidSelectedIndex.Value = SelectedIndex.Value.ToString();
            }

            this.Controls.Add(hidSelectedIndex);
            base.OnLoad(e);
        }


        protected override void EnsureChildControls()
        {
            base.EnsureChildControls();
        }

        protected override void Render(HtmlTextWriter writer)
        {
            writer.WriteLine("<div id='" + this.ID + "'>");
            writer.WriteLine("<ul>");
            int i= 0;

            foreach (AprMenuItem menuItem in menuItems)
            {
                if (menuItem.Visible)
                {
                    writer.WriteLine("<li><a href='#" + this.ID + "_" + i + "'>" + menuItem.DisplayText + "</a></li>");
                    i++;
                }
                else
                {
                    Controls.Remove(menuItem.UpdatePanel);
                }
            }

            writer.WriteLine("</ul>");

            base.Render(writer);

            writer.WriteLine("</div>");
        }

        protected override void CreateChildControls()
        {
            int i = 0;
                        
            foreach (AprMenuItem menuItem in menuItems)
            {
                if (menuItem.Visible)
                {
                    menuItem.UpdatePanel.ClientIDMode = System.Web.UI.ClientIDMode.Static;
                    menuItem.UpdatePanel.ID= this.ID + "_" + i;
                    menuItem.UpdatePanel.UpdateMode = UpdatePanelUpdateMode.Conditional;

                    //Build menu template
                    menuItem.Template.InstantiateIn(menuItem.UpdatePanel.ContentTemplateContainer);

                    Controls.Add(menuItem.UpdatePanel);
                    i++;
                }
            }
            base.CreateChildControls();
        }

        protected override void OnPreRender(EventArgs e)
        {
            string js= "$(function () {$('#" + this.ID + "').tabs({";

            js += "activate: function() { var selectedTab = $('#" + this.ID + "').tabs('option', 'active');";
            js += "$('#" + this.hidSelectedIndex.ClientID + "').val(selectedTab); }";

            if (SelectedIndex.HasValue)
            {
                js += ", selected: " + SelectedIndex;

                this.menuItems[SelectedIndex.Value].UpdatePanel.Update();
            }
            if (ShowOnlyFirstMenuItem)
            {
                js += ", disabled: [" + GetNumberOfTabs(1) + "] ";
            }
            js += "});";

            if (!ShowOnlyFirstMenuItem && this.menuItems.Count > 1)
            {
                js += "$('#" + this.ID + "').tabs('enable');";
            }
            if (SelectedIndex.HasValue)
            {
                js += "$('#" + this.ID + "').tabs({ active: " + SelectedIndex.Value + " });";
            }
            js += "});";

            ScriptManager.RegisterStartupScript(this.Page, this.GetType(),  "AprMenu" + this.ClientID, js, true);
           
            base.OnPreRender(e);
        }

      
        private string GetNumberOfTabs(int startTab)
        {
            string numberOfTabs= "";
            for (int i = startTab; i < MenuItems.Count; i++) 
            {
                if (MenuItems[i].Visible)
                    numberOfTabs+= i.ToString() + ",";
            }
            if(numberOfTabs.Length > 0)
            {
                numberOfTabs= numberOfTabs.Substring(0, numberOfTabs.Length-1);
            }
            return numberOfTabs;
        }

        public void UpdatePanel(int panelIndex)
        {
            this.MenuItems[panelIndex].UpdatePanel.Update();
        }
    }

    [ParseChildren(true, "Template"), PersistChildren(false)]
    public class AprMenuItem: Control, INamingContainer
    {
        public string DisplayText = "";
        public UpdatePanel UpdatePanel = new UpdatePanel();

        private ITemplate template;
        [PersistenceMode(PersistenceMode.InnerProperty)]
        [TemplateInstanceAttribute(TemplateInstance.Single)]
        public ITemplate Template
        {
            get
            {
                return template;
            }
            set
            {
                template = value;
            }
        }
        
    }
}
