﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Enums;
using AutoProofreader.Managers;
using AutoProofreader.UI;
using AutoProofreader.Utils;

namespace AutoProofreader.UI.WebControls
{
    public class AprQuestion : WebControl
    {
        private int questionNumber;
        private Question question = null;

        private AprLabel lb_QuestionNumber = null;
        private AprLabel lb_QuestionDescription = null;
        private Panel pnl_Answers = null;
        private Literal li_FreeTextFeedback = null;
        private ListControl answersListControl = null;
        private AprTextBox txtFreeTextAnswer = null;

        public AprQuestion(int _questionNumber, Question _question)
        {
            this.questionNumber = _questionNumber;
            this.question = _question;

            if (question.AnswerList == null)
            {
                question.LoadAnswers();
            }
        }

        protected override void OnInit(EventArgs e)
        {
            this.lb_QuestionNumber = new AprLabel();
            this.lb_QuestionNumber.CssClass = "questionNumber";
            this.lb_QuestionDescription = new AprLabel();
            this.pnl_Answers = new Panel();
            this.CssClass = "question";

            AddControls();

            base.OnInit(e);
        }

        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);
        }

        protected void AddControls()
        {
            this.Controls.Clear();

            lb_QuestionNumber.Text = this.questionNumber.ToString();

            lb_QuestionDescription.Text = question.QuestionDescription;
            
            if (question.AnswersType.Value == AnswersType.FreeText)
            {
                HtmlGenericControl div = new HtmlGenericControl("div");
                div.Attributes.Add("class", "answerList");

                txtFreeTextAnswer = new AprTextBox();

                if (question.AnswerList.Count > 0 && !string.IsNullOrEmpty(question.AnswerList[0].AttemptValue))
                {
                    txtFreeTextAnswer.Text = question.AnswerList[0].AttemptValue;
                }

                
                div.Controls.Add(txtFreeTextAnswer);

                li_FreeTextFeedback = new Literal();
                div.Controls.Add(li_FreeTextFeedback);              

                this.pnl_Answers.Controls.Add(div);
            }
            else
            {
                if (question.AnswersType.Value == AnswersType.OneCorrect)
                {
                    answersListControl = new RadioButtonList();
                }
                if (question.AnswersType.Value == AnswersType.MultipleCorrect)
                {
                    answersListControl = new CheckBoxList();
                }
                answersListControl.CssClass = "answerList";

                answersListControl.Items.Clear();

                foreach (Answer answer in question.AnswerList)
                {
                    ListItem listItem = new ListItem();
                    listItem.Text = answer.AnswerDescription;
                    listItem.Value = answer.AnswerNumber.ToString();

                    if (question.AnswersType.Value == AnswersType.OneCorrect)
                    {
                        listItem.Attributes.Add("class", "span-css-radio");
                    }
                    if (question.AnswersType.Value == AnswersType.MultipleCorrect)
                    {
                        listItem.Attributes.Add("class", "span-css-checkbox");    
                    }

                    if (!string.IsNullOrEmpty(answer.AttemptValue) &&
                         answer.AttemptValue == Boolean.TrueString)
                    {
                        listItem.Selected = true;                        
                    }


                    answersListControl.Items.Add(listItem);
                }

                this.pnl_Answers.Controls.Add(answersListControl);
            }

            this.Controls.Add(lb_QuestionNumber);
            this.Controls.Add(lb_QuestionDescription);

            //Multimedia - Image
            if (question.ExistImage())
            {             
                string imagePath = question.GetImagePath();

                Image imgQuestion = new Image();
                imgQuestion.ImageUrl = imagePath;

                HtmlGenericControl p = new HtmlGenericControl("p");
                p.Controls.Add(imgQuestion);

                this.Controls.Add(p);
            }

            //Multimedia - Sound
            if (question.ExistSound())
            {
                string soundPath = question.GetSoundPath();

                AprSound sound = new AprSound();
                sound.SoundUrl = soundPath;

                HtmlGenericControl p = new HtmlGenericControl("p");
                p.Controls.Add(sound);

                this.Controls.Add(p);
            }


            this.Controls.Add(pnl_Answers);


            HtmlGenericControl hr = new HtmlGenericControl("hr");
            this.Controls.Add(hr);

        }

        protected override void OnPreRender(EventArgs e)
        {
            base.OnPreRender(e);
        }

        protected override System.Web.UI.HtmlTextWriterTag TagKey
        {
            get
            {
                return HtmlTextWriterTag.Div;
            }
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns>0 to 1</returns>
        public void Correct()
        {
            UpdateAttemptValues();

            if (question.AnswersType.Value == AnswersType.FreeText)
            {                
                if (question.AnswerList.Count > 0)
                {
                    Answer answer = question.AnswerList[0];
                    question.Correct();

                    if (question.Result == 1)
                    {
                        li_FreeTextFeedback.Text = GetCorrectHint(answer.IsCorrectHint);
                    }
                    else
                    {
                        li_FreeTextFeedback.Text = GetIncorrectHint(answer.IsIncorrectHint);
                    }
                }

                txtFreeTextAnswer.Enabled = false;
            }
            else
            {
                for (int i = 0; i < answersListControl.Items.Count; i++)
                {
                    ListItem listItem = answersListControl.Items[i];
                    if (listItem.Selected)
                    {
                        Answer answer = question.AnswerList[i];
                        if (answer.Correct())
                        {
                            listItem.Text += GetCorrectHint(answer.IsCorrectHint);
                        }
                        else
                        {
                            listItem.Text += GetIncorrectHint(answer.IsIncorrectHint);
                        }
                    }
                    listItem.Attributes.Add("onclick", "return false;");
                }                
            }
        }

        public void UpdateAttemptValues()
        {
            if (question.AnswersType.Value == AnswersType.FreeText)
            {                
                if (question.AnswerList.Count > 0)
                {
                    Answer answer = question.AnswerList[0];
                    answer.UserValue = txtFreeTextAnswer.Text;                 
                }
            }
            else
            {
                for (int i = 0; i < answersListControl.Items.Count; i++)
                {
                    ListItem listItem = answersListControl.Items[i];

                    if (listItem.Selected)
                    {
                        Answer answer = question.AnswerList[i];
                        answer.UserValue = listItem.Selected.ToString();
                    }
                }
            }
        }

        private string GetCorrectHint(string correctHint)
        {
            string html = "<label class='correct'><i class='mediumFont fa fa-check seafoam_green'></i>";
            html += "&nbsp;" + correctHint + "</label>";
            return html;
        }

        private string GetIncorrectHint(string incorrectHint)
        {
            string html = "<label class='incorrect'><i class='mediumFont fa fa-close seafoam_red'></i>";
            html += "&nbsp;" + incorrectHint + "</label>";
            return html;
        }
    }
}
