﻿using System;
using System.Data;
using System.Configuration;
using System.Data.SqlClient;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.Utils;
using AutoProofreader.Security;

namespace AutoProofreader.BusinessObjects
{    
    /// <summary>
    /// Base business object class. 
    /// Any domain business objet must implement this class, which provides common properties and methods shared among all the business objects
    /// </summary>
    [Serializable]
    public abstract class BaseBusinessObject
    {
        protected DateTime? createdDate;

        public DateTime? CreatedDate
        {
            get { return createdDate; }
            set { createdDate = value; }
        }
        protected User createdBy;

        public User CreatedBy
        {
            get { return createdBy; }
            set { createdBy = value; }
        }
        protected DateTime? updatedDate;

        public DateTime? UpdatedDate
        {
            get { return updatedDate; }
            set { updatedDate = value; }
        }
        protected User updatedBy;

        public User UpdatedBy
        {
            get { return updatedBy; }
            set { updatedBy = value; }
        }
        protected bool isDeleted= false;

        public bool IsDeleted
        {
            get { return isDeleted; }
            set { isDeleted = value; }
        }

        [NonSerialized]
        protected SecurityProvider securityProvider;


        /// <summary>
        /// Default constructor.
        /// </summary>
        public BaseBusinessObject()
        {
            securityProvider = new SecurityProvider(); 
        }

        public abstract void FromDataReader(IDataReader dataReader);

        /// <summary>
        /// Loads the business object 
        /// </summary>
        /// <returns>True if the business object has been found</returns>        
        protected bool Load(IDataReader dataReader) 
        {
            bool loaded = false;
            if (dataReader.Read())
            {
                loaded = true;
                FromDataReader(dataReader);
            }
            dataReader.Close();

            return loaded;
        }


        /// <summary>
        /// Fills business object properties from a data reader
        /// </summary>
        /// <param name="businessObject">The business object</param>
        /// <param name="dataReader">the data reader to read from</param>
        protected static void FromDataReader(BaseBusinessObject businessObject, IDataReader dataReader)
        {
            businessObject.createdBy = new User();
            businessObject.updatedBy = new User();

            businessObject.createdBy.UserId = DbUtils.ReadLong(dataReader, "CreatedBy");
            businessObject.createdDate = DbUtils.ReadDate(dataReader, "CreatedDate");
            businessObject.updatedBy.UserId = DbUtils.ReadLong(dataReader, "UpdatedBy");
            businessObject.updatedDate = DbUtils.ReadDate(dataReader, "UpdatedDate");
            businessObject.isDeleted = DbUtils.ReadBoolValue(dataReader, "IsDeleted");
        }

    }
}
