﻿using System.Data;

namespace AutoProofreader.BusinessObjects
{
    /// <summary>
    /// Business object interface. 
    /// Any domain business object must define below methods
    /// </summary>
    public interface IBusinessObject
    {

        /// <summary>
        /// Fills business object properties from a data reader
        /// </summary>
        /// <param name="dataReader">the data reader to read from</param>

        void FromDataReader(IDataReader dataReader);

        /// <summary>
        /// Checks whether the business object already exists on the system
        /// </summary>
        /// <returns>True if the underlaying business object primary key has been set up</returns>

        bool Exists();
        /// <summary>
        /// Loads the business object by its underlaying primary key
        /// </summary>
        /// <returns>True if the business object has been found</returns>

        bool Load();

        /// <summary>
        /// Saves the business object to the database.
        /// If the business object already exists, it will update it, whereas if it doesn't it will add it
        /// </summary>


        void Save();
    }
}
