﻿using System;
using System.Data.Common;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Transactions;
using System.Threading.Tasks;
using AutoProofreader.Dao.SqlServer;

namespace AutoProofreader.Dao
{
    /// <summary>
    /// An agnostic transaction implementation.
    /// </summary>
    public class DaoTransaction : IDisposable
    {
        internal CommittableTransaction transaction;

        internal void Initialize()
        {
            if (this.transaction == null)
            {
                TransactionOptions transactionOptions = new TransactionOptions();
                transactionOptions.IsolationLevel = IsolationLevel.ReadCommitted;
                this.transaction = new CommittableTransaction(transactionOptions);
            }
        }

        public void Commit()
        {
            if (transaction != null)
            {
                this.transaction.Commit();
            }
            Dispose();
        }

        public void Rollback()
        {
            if (transaction != null)
            {
                this.transaction.Rollback();
            }
            Dispose();
        }

        /// <summary>
        /// Disposes the current transaction.
        /// </summary>
        public void Dispose()
        {
            Dispose(true);
        }

        /// <summary>
        /// Disposes the current transaction.
        /// </summary>
        protected virtual void Dispose(bool disposing)
        {
            if (disposing)
            {
                if (transaction != null)
                {
                    this.transaction.Dispose();
                    this.transaction = null;
                }
            }
        }

    }
}


