﻿using System;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.Exceptions;

namespace AutoProofreader.Dao.SqlServer
{
    public class AnswerDAO:BaseDAO, IAnswerDAO
    {
        private const string ERROR_SAVING = "Error guardant la resposta";
        private const string ERROR_SELECTING= "Eror recuperant la resposta";

        public AnswerDAO():base()
        { 
            
        }

        public int Add(long questionId, string answerDescription, string isCorrectHint, string isIncorrectHint, string correctValue)
        {
            int answerNumber;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Answers_Insert");
                AddParameter(dbCommand, DbType.Int64, "QuestionId", questionId);
                AddParameter(dbCommand, DbType.String, "AnswerDescription", answerDescription);
                AddParameter(dbCommand, DbType.String, "IsCorrectHint", isCorrectHint);
                AddParameter(dbCommand, DbType.String, "IsIncorrectHint", isIncorrectHint);
                AddParameter(dbCommand, DbType.String, "CorrectValue", correctValue);

                AddOutputParameter(dbCommand, DbType.Int32, "AnswerNumber", 0);

                ExecuteCommand(dbCommand);
                answerNumber = (int)GetParameterValue(dbCommand, "AnswerNumber");
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return answerNumber;
        }

        public void Delete(long questionId, long answerNumber)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Answers_Delete");
                AddParameter(dbCommand, DbType.Int64, "QuestionId", questionId);
                AddParameter(dbCommand, DbType.Int32, "AnswerNumber", answerNumber);

                ExecuteCommand(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }

        public void Update(long questionId, long answerNumber, string answerDescription, string isCorrectHint, string isIncorrectHint, string correctValue)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Answers_Update");
                AddParameter(dbCommand, DbType.Int64, "QuestionId", questionId);
                AddParameter(dbCommand, DbType.Int32, "AnswerNumber", answerNumber);
                AddParameter(dbCommand, DbType.String, "AnswerDescription", answerDescription);
                AddParameter(dbCommand, DbType.String, "IsCorrectHint", isCorrectHint);
                AddParameter(dbCommand, DbType.String, "IsIncorrectHint", isIncorrectHint);
                AddParameter(dbCommand, DbType.String, "CorrectValue", correctValue);

                ExecuteCommand(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }

        public IDataReader ListByQuestionId(long questionId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Answers_GetByQuestionId");
                AddParameter(dbCommand, DbType.Int64, "questionId", questionId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }
        
        public IDataReader GetById(long questionId, long answerNumber)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Answers_GetByID");
                AddParameter(dbCommand, DbType.Int64, "QuestionId", questionId);
                AddParameter(dbCommand, DbType.Int32, "AnswerNumber", answerNumber);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }
        
    }
}
