﻿using System;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.Exceptions;

namespace AutoProofreader.Dao.SqlServer
{
    public class AttemptDAO: BaseDAO, IAttemptDAO
    {
        private const string ERROR_SAVING = "Error guardant l'intent";
        private const string ERROR_SELECTING = "Eror recuperant l'intent";

        public AttemptDAO()
            : base()
        { 
            
        }

        public long Add(DaoTransaction transaction, long classroomId, long testId, long userId, DateTime startDate, DateTime? endDate, string score)
        {
            long attemptId;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Attempts_Insert");
                AddParameter(dbCommand, DbType.Int64, "ClassroomID", classroomId);
                AddParameter(dbCommand, DbType.Int64, "TestID", testId);
                AddParameter(dbCommand, DbType.Int64, "UserID", userId);
                AddParameter(dbCommand, DbType.DateTime, "StartDate", startDate);
                AddParameter(dbCommand, DbType.DateTime, "EndDate", endDate);
                AddParameter(dbCommand, DbType.String, "Score", score);

                AddOutputParameter(dbCommand, DbType.Int64, "AttemptID", 0);

                ExecuteCommand(dbCommand, transaction);
                attemptId = (long)GetParameterValue(dbCommand, "AttemptID");
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }

            return attemptId;
        }

        public void Update(DaoTransaction transaction, long attemptId, DateTime endDate, string score)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Attempts_Upate");

                AddParameter(dbCommand, DbType.Int64, "AttemptID", attemptId);
                AddParameter(dbCommand, DbType.DateTime, "EndDate", endDate);
                AddParameter(dbCommand, DbType.String, "Score", score);

                ExecuteCommand(dbCommand, transaction);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }


        public void AddQuestion(DaoTransaction transaction, long attemptId, long questionId, float? result)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Attempts_Questions_Insert");
                AddParameter(dbCommand, DbType.Int64, "AttemptId", attemptId);
                AddParameter(dbCommand, DbType.Int64, "QuestionID", questionId);
                AddParameter(dbCommand, DbType.Single, "Result", result);

                ExecuteCommand(dbCommand, transaction);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }

        public void UpdateQuestion(DaoTransaction transaction, long attemptId, long questionId, float? result)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Attempts_Questions_Update");

                AddParameter(dbCommand, DbType.Int64, "AttemptId", attemptId);
                AddParameter(dbCommand, DbType.Int64, "QuestionID", questionId);
                AddParameter(dbCommand, DbType.Single, "Result", result);

                ExecuteCommand(dbCommand, transaction);

            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }

        public void AddQuestionAnswer(DaoTransaction transaction, long attemptId, long questionId, int answerNumber, string attemptValue)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Attempts_Questions_Answers_Insert");
                AddParameter(dbCommand, DbType.Int64, "AttemptId", attemptId);
                AddParameter(dbCommand, DbType.Int64, "QuestionID", questionId);
                AddParameter(dbCommand, DbType.Int32, "AnswerNumber", answerNumber);
                AddParameter(dbCommand, DbType.String, "AttemptValue", attemptValue);

                ExecuteCommand(dbCommand, transaction);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }
        public void UpdateQuestionAnswer(DaoTransaction transaction, long attemptId, long questionId, int answerNumber, string attemptValue)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Attempts_Questions_Answers_Update");
                AddParameter(dbCommand, DbType.Int64, "AttemptID", attemptId);
                AddParameter(dbCommand, DbType.Int64, "QuestionID", questionId);
                AddParameter(dbCommand, DbType.Int32, "AnswerNumber", answerNumber);
                AddParameter(dbCommand, DbType.String, "AttemptValue", attemptValue);

                ExecuteCommand(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }

        }

        public IDataReader GetById(long attemptId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Attempts_GetById");
                AddParameter(dbCommand, DbType.Int64, "AttemptId", attemptId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader ListByClassroomIdTestIdUserId(long classroomId, long testId, long userId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Attempts_GetByClassroomIdTestIdUserId");
                AddParameter(dbCommand, DbType.Int64, "ClassroomId", classroomId);
                AddParameter(dbCommand, DbType.Int64, "TestId", testId);
                AddParameter(dbCommand, DbType.Int64, "UserId", userId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader ListByClassroomIdUserId(long classroomId, long userId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Attempts_GetByClassroomIdUserId");
                AddParameter(dbCommand, DbType.Int64, "ClassroomId", classroomId);
                AddParameter(dbCommand, DbType.Int64, "UserId", userId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader ListForStudent(long userId, string editStatus)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Attempts_GetForStudent");
                AddParameter(dbCommand, DbType.Int64, "UserId", userId);
                AddParameter(dbCommand, DbType.String, "EditStatus", editStatus);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;

        }

        public IDataReader ListHistoryForStudent(long userId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Attempts_GetHistoryForStudent");
                AddParameter(dbCommand, DbType.Int64, "UserId", userId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;

        }
        public IDataReader GetNumberOfAttempts(long testId, long classroomId, long userId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Attempts_GetNumberOfAttempts");
                AddParameter(dbCommand, DbType.Int64, "TestID", testId);
                AddParameter(dbCommand, DbType.Int64, "ClassroomID", classroomId);
                AddParameter(dbCommand, DbType.Int64, "UserID", userId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }
    }
}
