﻿using System;
using System.Data;
using System.Configuration;
using System.Data.SqlClient;
using System.Data.Common;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Microsoft.Practices.EnterpriseLibrary.Data;
using Microsoft.Practices.EnterpriseLibrary.Data.Sql;

namespace AutoProofreader.Dao.SqlServer
{
    /// <summary>
    /// Dao base class.
    /// Built at the top of Microsoft Enterprise Library Data block, which provides a good connection pooling mechanism.
    /// 
    /// </summary>
    public class BaseDAO
    {
        protected const int DUPLICATE_KEY_ERROR_CODE = 2627;

        private SqlDatabase database= null;

        public BaseDAO()
        {
            
            string connectionString = ConfigurationManager.ConnectionStrings["AutoProofreader"].ConnectionString;
            this.database = new SqlDatabase(connectionString);
        }

        private SqlTransaction GetTransaction()
        {
            return null;
        }

        protected DbCommand GetCommand(string commandName)
        {
            DbCommand dbCommand= database.GetStoredProcCommand(commandName);
            return dbCommand;
        }

        protected int ExecuteCommand(DbCommand dbCommand)
        {
            return database.ExecuteNonQuery(dbCommand);
        }

        protected int ExecuteCommand(DbCommand dbCommand, DaoTransaction transaction)
        {
            if (transaction != null)
                transaction.Initialize();

            return database.ExecuteNonQuery(dbCommand);
        }

        protected int ExecuteIntScalar(DbCommand dbCommand)
        {
            return (int)database.ExecuteScalar(dbCommand);
        }

        protected void AddParameter(DbCommand dbCommand, DbType dbType,  string parameterName, object parameterValue)
        {
            database.AddInParameter(dbCommand, parameterName, dbType, parameterValue);
        }

        protected void AddOutputParameter(DbCommand dbCommand, DbType dbType, string parameterName, int size)
        {
            database.AddOutParameter(dbCommand, parameterName, dbType, size);
        }

        protected object GetParameterValue(DbCommand dbCommand, string parameterName)
        {
            return database.GetParameterValue(dbCommand, parameterName);  
        }
           
        protected IDataReader GetReader(DbCommand dbCommand)
        {
            return database.ExecuteReader(dbCommand);
        }

        protected void AddCreatedParameters(DbCommand dbCommand, DateTime createdDate, long createdBy, bool isDeleted)
        {
            AddParameter(dbCommand, DbType.DateTime, "CreatedDate", createdDate);
            AddParameter(dbCommand, DbType.Int64, "CreatedBy", createdBy);
            AddParameter(dbCommand, DbType.Boolean, "IsDeleted", isDeleted);
        }

        protected void AddUpdatedParameters(DbCommand dbCommand, DateTime updateDate, long updatedBy, bool isDeleted)
        {
            AddParameter(dbCommand, DbType.DateTime, "UpdatedDate", updateDate);
            AddParameter(dbCommand, DbType.Int64, "UpdatedBy", updatedBy);
            AddParameter(dbCommand, DbType.Boolean, "IsDeleted", isDeleted);
        }

        protected void AddSortPagerParameters(DbCommand dbCommand, string sortColumn, string sortDirection, int maximumRows, int startRowIndex)
        {
            AddSortParameters(dbCommand, sortColumn, sortDirection);
            AddPagerParameters(dbCommand, maximumRows, startRowIndex);
        }

        protected void AddSortParameters(DbCommand dbCommand, string sortColumn, string sortDirection)
        {
            AddParameter(dbCommand, DbType.String, "SortColumn", sortColumn);
            AddParameter(dbCommand, DbType.String, "SortDirection", sortDirection);
        }

        protected void AddPagerParameters(DbCommand dbCommand, int maximumRows, int startRowIndex)
        {
            AddParameter(dbCommand, DbType.Int32, "MaximumRows", maximumRows);
            AddParameter(dbCommand, DbType.Int32, "StartRowIndex", startRowIndex + 1);
        }

    }
}


