﻿using System;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.Exceptions;

namespace AutoProofreader.Dao.SqlServer
{
    public class CategoryDAO:BaseDAO, ICategoryDAO
    {
        private const string ERROR_SAVING = "Error guardant la categoria";
        private const string ERROR_SELECTING = "Eror recuperant la categoria";

        public CategoryDAO()
            : base()
        { 
            
        }

        public long Add(DaoTransaction transaction, string categoryName, DateTime createdDate, long createdBy, bool isDeleted)
        {
            long categoryId;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Categories_Insert");
                AddParameter(dbCommand, DbType.String, "CategoryName", categoryName);

                AddCreatedParameters(dbCommand, createdDate, createdBy, isDeleted);

                AddOutputParameter(dbCommand, DbType.Int64, "CategoryID", 0);

                ExecuteCommand(dbCommand, transaction);
                categoryId = (long)GetParameterValue(dbCommand, "CategoryID");
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }

            return categoryId;
        }

        public void Update(DaoTransaction transaction, long categoryId, string categoryName, DateTime updateDate, long updatedBy, bool isDeleted)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Categories_Update");

                AddParameter(dbCommand, DbType.Int64, "CategoryId", categoryId);
                AddParameter(dbCommand, DbType.String, "CategoryName", categoryName);

                AddUpdatedParameters(dbCommand, updateDate, updatedBy, isDeleted);

                ExecuteCommand(dbCommand, transaction);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }

        public IDataReader GetById(long categoryId) 
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Categories_GetById");
                AddParameter(dbCommand, DbType.Int64, "CategoryID", categoryId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader List()
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Categories_List");
                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }        
        public IDataReader ListByQuestionEditStatus(string editStatus)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Categories_List_ByQuestionEditStatus");
                AddParameter(dbCommand, DbType.String, "EditStatus", editStatus);
                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader Select(string searchText, bool isDeleted, int maximumRows, int startRowIndex, string sortColumn, string sortDirection)
        {
            IDataReader dataReader = null;

            try
            {
                searchText = "%" + searchText + "%";

                DbCommand dbCommand = GetCommand("usp_Categories_Select");
                AddParameter(dbCommand, DbType.String, "SearchText", searchText);
                AddParameter(dbCommand, DbType.Boolean, "IsDeleted", isDeleted);

                AddSortPagerParameters(dbCommand, sortColumn, sortDirection, maximumRows, startRowIndex);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public int Count(string searchText, bool isDeleted)
        {
            int count = 0;

            try
            {
                searchText = "%" + searchText + "%";

                DbCommand dbCommand = GetCommand("usp_Categories_Count");

                AddParameter(dbCommand, DbType.String, "SearchText", searchText);
                AddParameter(dbCommand, DbType.Boolean, "IsDeleted", isDeleted);

                count = ExecuteIntScalar(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return count;
        }

    }
}
