﻿using System;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.Exceptions;

namespace AutoProofreader.Dao.SqlServer
{
    public class ClassroomDAO:BaseDAO, IClassroomDAO
    {
        private const string ERROR_SAVING = "Error guardant l'aula";
        private const string ERROR_SELECTING = "Eror recuperant l'aula";

        public ClassroomDAO():base()
        { 
            
        }

        public long Add(DaoTransaction transaction, string classroomName, DateTime? startDate, DateTime? endDate, DateTime createdDate, long createdBy, bool isDeleted)
        {
            long classroomId;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Classrooms_Insert");
                AddParameter(dbCommand, DbType.String, "ClassroomName", classroomName);
                AddParameter(dbCommand, DbType.DateTime, "StartDate", startDate);
                AddParameter(dbCommand, DbType.DateTime, "EndDate", endDate);

                AddCreatedParameters(dbCommand, createdDate, createdBy, isDeleted);

                AddOutputParameter(dbCommand, DbType.Int64, "ClassroomID", 0);

                ExecuteCommand(dbCommand, transaction);
                classroomId = (long)GetParameterValue(dbCommand, "ClassroomID");
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }

            return classroomId;
        }

        public void Update(DaoTransaction transaction, long classroomId, string classroomName, DateTime? startDate, DateTime? endDate, DateTime updateDate, long updatedBy, bool isDeleted)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Classrooms_Update");

                AddParameter(dbCommand, DbType.Int64, "ClassroomId", classroomId);
                AddParameter(dbCommand, DbType.String, "ClassroomName", classroomName);
                AddParameter(dbCommand, DbType.DateTime, "StartDate", startDate);
                AddParameter(dbCommand, DbType.DateTime, "EndDate", endDate);

                AddUpdatedParameters(dbCommand, updateDate, updatedBy, isDeleted);

                ExecuteCommand(dbCommand, transaction);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }

        public IDataReader GetById(long classroomId) 
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Classrooms_GetById");
                AddParameter(dbCommand, DbType.Int64, "ClassroomID", classroomId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader List()
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Classrooms_List");
                dataReader= GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader ListByUserId(long userId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Classrooms_ListByUser");
                AddParameter(dbCommand, DbType.Int64, "UserID", userId);
                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }


        public IDataReader ListByNotAssignedToUserId(long userId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Classrooms_ListByNotAssignedToUser");
                AddParameter(dbCommand, DbType.Int64, "UserID", userId);
                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader ListByTestId(long testId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Classrooms_ListByTest");
                AddParameter(dbCommand, DbType.Int64, "TestID", testId);
                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }


        public IDataReader ListByNotAssignedToTestId(long testId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Classrooms_ListByNotAssignedToTest");
                AddParameter(dbCommand, DbType.Int64, "TestID", testId);
                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader Select(string searchText, bool isDeleted, long? userId, int maximumRows, int startRowIndex, string sortColumn, string sortDirection)
        {
            IDataReader dataReader = null;

            try
            {
                searchText = "%" + searchText + "%";

                DbCommand dbCommand = GetCommand("usp_Classrooms_Select");
                AddParameter(dbCommand, DbType.String, "SearchText", searchText);
                AddParameter(dbCommand, DbType.Boolean, "IsDeleted", isDeleted);
                AddParameter(dbCommand, DbType.Int64, "UserId", userId);

                AddSortPagerParameters(dbCommand, sortColumn, sortDirection, maximumRows, startRowIndex);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public int Count(string searchText,bool isDeleted, long? userId)
        {
            int count = 0;

            try
            {
                searchText = "%" + searchText + "%";

                DbCommand dbCommand = GetCommand("usp_Classrooms_Count");

                AddParameter(dbCommand, DbType.String, "SearchText", searchText);
                AddParameter(dbCommand, DbType.Boolean, "IsDeleted", isDeleted);
                AddParameter(dbCommand, DbType.Int64, "UserId", userId);

                count = ExecuteIntScalar(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return count;
        }


        public void AssignUser(long classroomId, long userId)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Classrooms_Users_Insert");
                AddParameter(dbCommand, DbType.Int64, "ClassroomId", classroomId);
                AddParameter(dbCommand, DbType.Int64, "UserId", userId);

                ExecuteCommand(dbCommand);
            }            
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }

        public void UnassignUser(long classroomId, long userId)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Classrooms_Users_Delete");
                AddParameter(dbCommand, DbType.Int64, "ClassroomId", classroomId);
                AddParameter(dbCommand, DbType.Int64, "UserId", userId);

                ExecuteCommand(dbCommand);
            }          
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }
    }
}
