﻿using System;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.Exceptions;

namespace AutoProofreader.Dao.SqlServer
{
    public class LogDAO:BaseDAO, ILogDAO
    {
        private const string ERROR_SAVING = "Error guardant log";
        private const string ERROR_SELECTING = "Eror recuperant log";
        public LogDAO()
            : base()
        { 
            
        }

        public long Add(DaoTransaction transaction, string description, string logType, DateTime createdDate, long createdBy)
        {
            long logId;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Log_Insert");
                AddParameter(dbCommand, DbType.String, "Description", description);
                AddParameter(dbCommand, DbType.String, "LogType", logType);
                AddParameter(dbCommand, DbType.DateTime, "CreatedDate", createdDate);
                AddParameter(dbCommand, DbType.Int64, "CreatedBy", createdBy);
                AddOutputParameter(dbCommand, DbType.Int64, "LogId", 0);

                ExecuteCommand(dbCommand, transaction);
                logId = (long)GetParameterValue(dbCommand, "LogId");
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }

            return logId;
        }


        public IDataReader List(long userId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Log_List");
                AddParameter(dbCommand, DbType.Int64, "UserID", userId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader Select(long? userId, DateTime? startDate, DateTime? endDate, string logType, int startRowIndex, int maximumRows)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Log_Select");
                AddParameter(dbCommand, DbType.Int64, "UserId", userId);
                AddParameter(dbCommand, DbType.DateTime, "StartDate", startDate);
                AddParameter(dbCommand, DbType.DateTime, "EndDate", endDate);
                AddParameter(dbCommand, DbType.String, "LogType", logType);

                AddPagerParameters(dbCommand, maximumRows, startRowIndex);
                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public int Count(long? userId, DateTime? startDate, DateTime? endDate, string logType)
        {
            int count = 0;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Log_Count");
                AddParameter(dbCommand, DbType.Int64, "UserId", userId);
                AddParameter(dbCommand, DbType.DateTime, "StartDate", startDate);
                AddParameter(dbCommand, DbType.DateTime, "EndDate", endDate);
                AddParameter(dbCommand, DbType.String, "LogType", logType);

                count = ExecuteIntScalar(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return count;
        }
    }
}
