﻿using System;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.Exceptions;

namespace AutoProofreader.Dao.SqlServer
{
    public class QuestionDAO:BaseDAO, IQuestionDAO
    {
        private const string ERROR_SAVING = "Error guardant pregunta";
        private const string ERROR_SELECTING = "Eror recuperant pregunta";

        public QuestionDAO():base()
        { 
            
        }

        public long Add(DaoTransaction transaction, string questionDescription, string editStatus, string answersType, long categoryId, DateTime createdDate, long createdBy, bool isDeleted)
        {
            long questionId;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Questions_Insert");
                AddParameter(dbCommand, DbType.String, "QuestionDescription", questionDescription);
                AddParameter(dbCommand, DbType.String, "EditStatus", editStatus);
                AddParameter(dbCommand, DbType.String, "AnswersType", answersType);
                AddParameter(dbCommand, DbType.Int64, "CategoryId", categoryId);

                AddCreatedParameters(dbCommand, createdDate, createdBy, isDeleted);

                AddOutputParameter(dbCommand, DbType.Int64, "QuestionID", 0);

                ExecuteCommand(dbCommand, transaction);
                questionId = (long)GetParameterValue(dbCommand, "QuestionId");
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }

            return questionId;
        }
        public void Update(long questionId, string questionDescription, long categoryId, DateTime updateDate, long updatedBy, bool isDeleted)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Questions_Update");

                AddParameter(dbCommand, DbType.Int64, "QuestionId", questionId);
                AddParameter(dbCommand, DbType.String, "QuestionDescription", questionDescription);
                AddParameter(dbCommand, DbType.Int64, "CategoryId", categoryId);

                AddUpdatedParameters(dbCommand, updateDate, updatedBy, isDeleted);

                ExecuteCommand(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }
        public void UpdateResources(long questionId, string imageResource, string soundResoure, DateTime updateDate, long updatedBy)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Questions_Update_Resources");

                AddParameter(dbCommand, DbType.Int64, "QuestionId", questionId);
                AddParameter(dbCommand, DbType.String, "ImageResource", imageResource);
                AddParameter(dbCommand, DbType.String, "SoundResource", soundResoure);
                AddParameter(dbCommand, DbType.DateTime, "UpdatedDate", updateDate);
                AddParameter(dbCommand, DbType.Int64, "UpdatedBy", updatedBy);                

                ExecuteCommand(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }

        public IDataReader ListByEditStatusCategoryId(string editStatus, long? categoryId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Questions_GetByEditStatusAndCategory");
                AddParameter(dbCommand, DbType.String, "EditStatus", editStatus);
                AddParameter(dbCommand, DbType.Int64, "CategoryId", categoryId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader ListByEditStatusCategoryId(string editStatus, long? categoryId, long? testId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Questions_GetByEditStatusAndCategory");
                AddParameter(dbCommand, DbType.String, "EditStatus", editStatus);
                AddParameter(dbCommand, DbType.Int64, "CategoryId", categoryId);
                AddParameter(dbCommand, DbType.Int64, "TestId", testId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }


        public IDataReader ListByTestId(long testId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Questions_GetByTestId");
                AddParameter(dbCommand, DbType.Int64, "TestId", testId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader ListByAttemptId(long attemptId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Questions_GetByAttemptId");
                AddParameter(dbCommand, DbType.Int64, "AttemptId", attemptId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader ListByCategoryId(long categoryId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Questions_GetByCategoryId");
                AddParameter(dbCommand, DbType.Int64, "CategoryId", categoryId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader GetById(long questionId) 
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Questions_GetById");
                AddParameter(dbCommand, DbType.Int64, "QuestionID", questionId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public void UpateEditStatus(DaoTransaction transaction, long testId, string editStatus)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Tests_Questions_UpdateEditStatus");

                AddParameter(dbCommand, DbType.Int64, "TestId", testId);
                AddParameter(dbCommand, DbType.String, "EditStatus", editStatus);

                ExecuteCommand(dbCommand, transaction);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }
        }
    }
}
