﻿using System;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.Exceptions;

namespace AutoProofreader.Dao.SqlServer
{
    public class TestDAO:BaseDAO, ITestDAO
    {
        private const string ERROR_SAVING = "Error guardant prova";
        private const string ERROR_SELECTING = "Eror recuperant prova";

        public TestDAO():base()
        { 
            
        }

        public long Add(DaoTransaction transaction, string testName, string testDescription, int? maxAttempts, int? questionsPerPage, int? resolutionMaxMinutes, string evaluationType, string editStatus, DateTime createdDate, long createdBy, bool isDeleted)
        {
            long testId;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Tests_Insert");
                AddParameter(dbCommand, DbType.String, "TestName", testName);
                AddParameter(dbCommand, DbType.String, "TestDescription", testDescription);
                AddParameter(dbCommand, DbType.Int16, "MaxAttempts", maxAttempts);
                AddParameter(dbCommand, DbType.Int16, "QuestionsPerPage", questionsPerPage);
                AddParameter(dbCommand, DbType.Int16, "ResolutionMaxMinutes", resolutionMaxMinutes);
                AddParameter(dbCommand, DbType.String, "EvaluationType", evaluationType);
                AddParameter(dbCommand, DbType.String, "EditStatus", editStatus);
                
                AddCreatedParameters(dbCommand, createdDate, createdBy, isDeleted);

                AddOutputParameter(dbCommand, DbType.Int64, "TestID", 0);

                ExecuteCommand(dbCommand, transaction);

                testId = (long)GetParameterValue(dbCommand, "TestId");
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }

            return testId;
        }
        public void Update(DaoTransaction transaction, long testId, string testName, string testDescription, int? maxAttempts, int? questionsPerPage, int? resolutionMaxMinutes, string evaluationType, string editStatus, DateTime updateDate, long updatedBy, bool isDeleted)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Tests_Update");

                AddParameter(dbCommand, DbType.Int64, "TestId", testId);
                AddParameter(dbCommand, DbType.String, "TestName", testName);
                AddParameter(dbCommand, DbType.String, "TestDescription", testDescription);
                AddParameter(dbCommand, DbType.Int16, "MaxAttempts", maxAttempts);
                AddParameter(dbCommand, DbType.Int16, "QuestionsPerPage", questionsPerPage);
                AddParameter(dbCommand, DbType.Int16, "ResolutionMaxMinutes", resolutionMaxMinutes);
                AddParameter(dbCommand, DbType.String, "EvaluationType", evaluationType);
                AddParameter(dbCommand, DbType.String, "EditStatus", editStatus);

                AddUpdatedParameters(dbCommand, updateDate, updatedBy, isDeleted);

                ExecuteCommand(dbCommand, transaction);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }

        public IDataReader GetById(long testId) 
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Tests_GetById");
                AddParameter(dbCommand, DbType.Int64, "TestID", testId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }



        public IDataReader Select(string searchText, bool isDeleted, string editStatus, long? createdBy)
        {
            IDataReader dataReader = null;

            try
            {
                searchText = "%" + searchText + "%";

                DbCommand dbCommand = GetCommand("usp_Tests_Select");

                AddParameter(dbCommand, DbType.String, "SearchText", searchText);
                AddParameter(dbCommand, DbType.Boolean, "IsDeleted", isDeleted);
                AddParameter(dbCommand, DbType.String, "EditStatus", editStatus);
                AddParameter(dbCommand, DbType.Int64, "CreatedBy", createdBy);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader ListByEditStatus(string editStatus)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Tests_List_ByEditStatus");

                AddParameter(dbCommand, DbType.String, "EditStatus", editStatus);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }
        public long AddQuestion(DaoTransaction transaction, long testId, long? questionId, long? categoryId)
        {
            long testQuestionId;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Tests_Questions_Insert");

                AddParameter(dbCommand, DbType.Int64, "TestID", testId);
                AddParameter(dbCommand, DbType.Int64, "QuestionID", questionId);
                AddParameter(dbCommand, DbType.Int64, "CategoryID", categoryId);
                AddOutputParameter(dbCommand, DbType.Int64, "TestQuestionId", 0);

                ExecuteCommand(dbCommand, transaction);

                testQuestionId = (long)GetParameterValue(dbCommand, "TestQuestionId");
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return testQuestionId;
        }

        public void RemoveQuestion(long testQuestionId)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Tests_Questions_Delete");

                AddParameter(dbCommand, DbType.Int64, "TestQuestionID", testQuestionId);

                ExecuteCommand(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }

        public void AddClassroom(long testId, long classroomId, DateTime startDate, DateTime endDate)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Classrooms_Tests_Insert");

                AddParameter(dbCommand, DbType.Int64, "ClassroomID", classroomId);
                AddParameter(dbCommand, DbType.Int64, "TestID", testId);
                AddParameter(dbCommand, DbType.DateTime, "StartDate", startDate);
                AddParameter(dbCommand, DbType.DateTime, "EndDate", endDate);

                ExecuteCommand(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }

     

    }
}
