﻿using System;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.Exceptions;

namespace AutoProofreader.Dao.SqlServer
{
    public class UserDAO:BaseDAO, IUserDAO
    {
        private const string ERROR_SAVING = "Error guardant usuari";
        private const string ERROR_SELECTING = "Eror recuperant usuari";
        public UserDAO():base()
        { 
            
        }

        public long Add(DaoTransaction transaction, string userName, string password, string userType, string firstName, string lastName, DateTime createdDate, long createdBy, bool isDeleted)
        {
            long userId;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Users_Insert");
                AddParameter(dbCommand, DbType.String, "UserName", userName);
                AddParameter(dbCommand, DbType.String, "Password", password);
                AddParameter(dbCommand, DbType.String, "UserType", userType);
                AddParameter(dbCommand, DbType.String, "FirstName", firstName);
                AddParameter(dbCommand, DbType.String, "LastName", lastName);

                AddCreatedParameters(dbCommand, createdDate, createdBy, isDeleted);

                AddOutputParameter(dbCommand, DbType.Int64, "UserID", 0);

                ExecuteCommand(dbCommand, transaction);
                userId = (long) GetParameterValue(dbCommand, "UserId");
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }

            return userId;
        }

        public void Update(DaoTransaction transaction, long userId, string userName, string userType, string firstName, string lastName, DateTime updateDate, long updatedBy, bool isDeleted)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Users_Update");

                AddParameter(dbCommand, DbType.Int64, "UserId", userId);
                AddParameter(dbCommand, DbType.String, "UserName", userName);
                AddParameter(dbCommand, DbType.String, "UserType", userType);
                AddParameter(dbCommand, DbType.String, "FirstName", firstName);
                AddParameter(dbCommand, DbType.String, "LastName", lastName);

                AddUpdatedParameters(dbCommand, updateDate, updatedBy, isDeleted);

                ExecuteCommand(dbCommand, transaction);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }

        public void UpdatePassword(DaoTransaction transaction, long userId, string password, DateTime updateDate, long updatedBy)
        {
            try
            {
                DbCommand dbCommand = GetCommand("usp_Users_Update_Password");

                AddParameter(dbCommand, DbType.Int64, "UserId", userId);
                AddParameter(dbCommand, DbType.String, "Password", password);
                AddParameter(dbCommand, DbType.DateTime, "UpdatedDate", updateDate);
                AddParameter(dbCommand, DbType.Int64, "UpdatedBy", updatedBy);

                ExecuteCommand(dbCommand, transaction);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SAVING, ex);
            }
        }

        public IDataReader GetById(long userId) 
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Users_GetById");
                AddParameter(dbCommand, DbType.Int64, "UserID", userId);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader GetByUserName(string userName)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Users_GetByUserName");
                AddParameter(dbCommand, DbType.String, "UserName", userName);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader GetByUserNameAndPassword(string userName, string password)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Users_GetByUserNameAndPassword");
                AddParameter(dbCommand, DbType.String, "UserName", userName);
                AddParameter(dbCommand, DbType.String, "Password", password);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader List()
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Users_List");
                dataReader= GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }


        public IDataReader ListByClassroomId(long classroomId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Users_List_ByClassroomId");
                AddParameter(dbCommand, DbType.Int64, "ClassroomId", classroomId);
                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader ListByNotClassroomId(long classroomId)
        {
            IDataReader dataReader = null;

            try
            {
                DbCommand dbCommand = GetCommand("usp_Users_List_ByNotClassroomId");
                AddParameter(dbCommand, DbType.Int64, "ClassroomId", classroomId);
                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public IDataReader Select(string searchText, string userType, bool isDeleted, long? classroomId, int maximumRows, int startRowIndex, string sortColumn, string sortDirection)
        {
            IDataReader dataReader = null;

            try
            {
                searchText = "%" + searchText + "%";

                DbCommand dbCommand = GetCommand("usp_Users_Select");
                AddParameter(dbCommand, DbType.String, "SearchText", searchText);
                AddParameter(dbCommand, DbType.String, "UserType", userType);
                AddParameter(dbCommand, DbType.Boolean, "IsDeleted", isDeleted);
                AddParameter(dbCommand, DbType.Int64, "ClassroomId", classroomId);

                AddSortPagerParameters(dbCommand, sortColumn, sortDirection, maximumRows, startRowIndex);

                dataReader = GetReader(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return dataReader;
        }

        public int Count(string searchText, string userType, bool isDeleted, long? classroomId)
        {
            int count = 0;

            try
            {
                searchText = "%" + searchText + "%";

                DbCommand dbCommand = GetCommand("usp_Users_Count");

                AddParameter(dbCommand, DbType.String, "SearchText", searchText);
                AddParameter(dbCommand, DbType.String, "UserType", userType);
                AddParameter(dbCommand, DbType.Boolean, "IsDeleted", isDeleted);
                AddParameter(dbCommand, DbType.Int64, "ClassroomId", classroomId);

                count = ExecuteIntScalar(dbCommand);
            }
            catch (Exception ex)
            {
                throw new DatabaseException(ERROR_SELECTING, ex);
            }

            return count;
        }

    }
}
