﻿using System;
using System.ComponentModel;
using System.Reflection;
using System.IO;
using System.Net.Configuration;
using System.Net.Mail;
using System.Configuration;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Enums;
using AutoProofreader.Security;

namespace AutoProofreader.Email
{
    /// <summary>
    /// Provides email functionalities based on email templates are stored as embedded resource within this assembly.
    /// Emails are being sent through gmail which requieres some extra tweacking 
    /// </summary>
    public class EmailProvider
    {
        private const string EmailtemplateEmbededResourcePath = "AutoProofreader.Email";

        /// <summary>
        /// Sends an email to the created user containing its data
        /// </summary>
        /// <param name="email">user email</param>
        /// <param name="firstName">user first name</param>
        /// <param name="lastName">user last name</param>
        /// <param name="password">user random password</param>
        public static void SendCretedUserEmail(string email, string firstName, string lastName, string password)
        {
            string subject = "Corrector automàtic de la Uoc - Usuari creat";
            string body = "";

            //Get email template as embedded resource
            StreamReader streamReader = GetUserCreatedEmailTemplate();
            body= streamReader.ReadToEnd();

            body = body.Replace("#firstName#", firstName);
            body = body.Replace("#lastName#", lastName);
            body = body.Replace("#userName#", email); 
            body = body.Replace("#password#", password);
            try
            {
                SendEmailThroughGmail(email, subject, body);

            }
            catch (Exception e)
            {
                Log.Error(string.Format("Error enviant correu electrònic a l'usuari {0}", email), e);
                throw;
            }
        }

        /// <summary>
        /// Send reset password email
        /// </summary>
        /// <param name="email">user email</param>
        /// <param name="firstName">user first name</param>
        /// <param name="lastName">user last name</param>
        /// <param name="password">user random password</param>
        public static void SendPasswordEmail(string email, string firstName, string lastName, string password)
        {
            string subject = "Corrector automàtic de la Uoc- Contransenya actualitzada";
            string body = "";

            //Get email template as embedded resource
            StreamReader streamReader = GetSendPasswordEmailTemplate();
            body = streamReader.ReadToEnd();

            body = body.Replace("#firstName#", firstName);
            body = body.Replace("#lastName#", lastName);
            body = body.Replace("#userName#", email);
            body = body.Replace("#password#", password);
            try
            {
                SendEmailThroughGmail(email, subject, body);
            }
            catch (Exception e)
            {
                Log.Error(string.Format("Error enviant correu electrònic a l'usuari {0}", email), e);
                throw;
            }
        }


        /// <summary>
        /// Sends an email through gmail, some extra fields have to be passed through to it
        /// </summary>
        /// <param name="to">destination email</param>
        /// <param name="subject">email subject</param>
        /// <param name="body">email body</param>
        /// <returns>true if the email has been sent out</returns>
        private static void SendEmailThroughGmail(string to, string subject, string body)
        {
            SmtpClient smtpClient = new SmtpClient();

            //DO not send messages if deliveryMethod="SpecifiedPickupDirectory"
            if (smtpClient.Host != null)
            {
                System.Net.NetworkCredential credentials = (System.Net.NetworkCredential)smtpClient.Credentials;
                System.Web.Mail.MailMessage mailMessage = new System.Web.Mail.MailMessage();

                mailMessage.Fields.Add("http://schemas.microsoft.com/cdo/configuration/smtpserver", smtpClient.Host);
                mailMessage.Fields.Add("http://schemas.microsoft.com/cdo/configuration/smtpserverport", "465");
                mailMessage.Fields.Add("http://schemas.microsoft.com/cdo/configuration/sendusing", "2");
                mailMessage.Fields.Add("http://schemas.microsoft.com/cdo/configuration/smtpauthenticate", "1");
                mailMessage.Fields.Add("http://schemas.microsoft.com/cdo/configuration/sendusername", credentials.UserName);
                mailMessage.Fields.Add("http://schemas.microsoft.com/cdo/configuration/sendpassword", credentials.Password);
                mailMessage.Fields.Add("http://schemas.microsoft.com/cdo/configuration/smtpusessl", "true");
                mailMessage.From = credentials.UserName;
                mailMessage.To = to;
                mailMessage.Subject = subject;
                mailMessage.Body = body;
                mailMessage.BodyFormat = System.Web.Mail.MailFormat.Html;


                System.Web.Mail.SmtpMail.SmtpServer = smtpClient.Host + ":" + smtpClient.Port;
                System.Web.Mail.SmtpMail.Send(mailMessage);
            }
        }


        /// <summary>
        /// Just a callback to handle possible errors and save them to the log 
        /// </summary>
        /// <param name="sender">callback sender</param>
        /// <param name="e">async events</param>
        private static void SendCompletedCallback(object sender, AsyncCompletedEventArgs e)
        {
            User senderUser= (User)e.UserState;

            if (e.Cancelled)
            {
                Log.Error(string.Format("Error enviant correu electrònic a l'usuari {0}. L'enviament ha estat cancelat.", senderUser.UserName));
            }
            if (e.Error != null)
            {
                Log.Error(string.Format("Error enviant correu electrònic a l'usuari {0}.", senderUser.UserName), e.Error);
            }
            else
            {
                Log.Info(string.Format("Correu electrònic enviat a l'usuari {0}.", senderUser.UserName));
            }
        }
        private static StreamReader GetSendPasswordEmailTemplate()
        {
            return GetEmailTemplate("PasswordUpdated.html");
        }
        private static StreamReader GetUserCreatedEmailTemplate()
        {
            return GetEmailTemplate("UserCreated.html");
        }

        private static StreamReader GetEmailTemplate(string emailTemplateFileName)
        {
            //Get email template file name 
            string emailTemplate = EmailtemplateEmbededResourcePath + "." + emailTemplateFileName;

            try
            {
                Assembly assembly = Assembly.GetExecutingAssembly();
                return new StreamReader(assembly.GetManifestResourceStream(emailTemplate));
            }
            catch (Exception ex)
            {
                throw new Exception(string.Format("Unable to get email template embeded resource {0}", emailTemplate), ex);
            }
        }
    }
}
