﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace AutoProofreader.Enums
{
     [Serializable]
    public class EvaluationType:EnumBase
    {
        public const char OneToTen = 'T';
        public const char OneToHoundred = 'H';
        public const char AtoD = 'A';

        public EvaluationType(char _value):base(_value)
        {

        }

        public EvaluationType()
            : base()
        {

        }

        public override string ToString()
        {
            return EvaluationType.ToString(value);
        }


        public static string ToString(char value)
        {
            switch (value)
            {
                case EvaluationType.AtoD:
                    return "A - D";
                case EvaluationType.OneToHoundred:
                    return "0 - 100";
                case EvaluationType.OneToTen:
                    return "0 - 10";
            }
            return null;
        }

        public static EvaluationType FromString(string evaluationType)
        {
            if (!string.IsNullOrEmpty(evaluationType))
            {
                return new EvaluationType(Char.Parse(evaluationType));
            }
            else
            {
                return null;
            }
        }

        public static string GetEvaluationScore(EvaluationType evaluationType, float baseScore)
        {
            string evaluationScore;

            if (evaluationType.Value == EvaluationType.OneToHoundred)
            {
                evaluationScore = (baseScore * 10).ToString("0.00");
            }
            else
            {
                if (evaluationType.Value == EvaluationType.AtoD)
                {
                    evaluationScore = GetAtoDScore(baseScore / 2);
                }
                else
                {
                    evaluationScore = baseScore.ToString("0.00");
                }
            }

            return evaluationScore;
        }

        public static string GetAtoDScore(float baseScore)
        {
            if (baseScore < 40)
            {
                return "D";                
            }
            else
            {
                if (baseScore >= 40 && baseScore < 50)
                {
                    return "C-";
                }
                else
                {
                    if (baseScore >= 50 && baseScore < 60)
                    {
                        return "C+";
                    }
                    else
                    {
                        if (baseScore < 90)
                        {
                            return "B";
                        }
                        else
                        {
                            return "A";
                        }
                    }
                }            
            }
        }

    }
}
