﻿using System;
using System.Data.Common;
using System.Data;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Enums;
using AutoProofreader.Exceptions;
using AutoProofreader.Dao;
using AutoProofreader.Dao.SqlServer;
using AutoProofreader.Security;
using AutoProofreader.Utils;

namespace AutoProofreader.Managers
{
    public class AttemptManager
    {
        private static IAttemptDAO attemptDao = DaoProvider.GetAttemptDao();

        public static List<Attempt> List(Classroom classroom, Test test, User user)
        {
            List<Attempt> attemptList = new List<Attempt>();

            IDataReader dataReader = attemptDao.ListByClassroomIdTestIdUserId(classroom.ClassroomId.Value, test.TestId.Value, user.UserId.Value);

            while (dataReader.Read())
            {
                Attempt attempt = new Attempt();
                Attempt.FromDataReader(attempt, dataReader);
                attemptList.Add(attempt);
            }
            dataReader.Close();

            return attemptList;
        }

        public static List<Attempt> List(Classroom classroom, User user)
        {
            List<Attempt> attemptList = new List<Attempt>();

            IDataReader dataReader = attemptDao.ListByClassroomIdUserId(classroom.ClassroomId.Value, user.UserId.Value);

            while (dataReader.Read())
            {
                Attempt attempt = new Attempt();
                Attempt.FromDataReader(attempt, dataReader);

                attempt.Test.TestName = DbUtils.ReadString(dataReader, "TestName");
                attempt.Test.ResolutionMaxMinutes = DbUtils.ReadInt(dataReader, "ResolutionMaxMinutes");
                attemptList.Add(attempt);
            }
            dataReader.Close();

            return attemptList;
        }

        public static List<Attempt> ListForStudent()
        {
            SecurityProvider securityProvider = new SecurityProvider();

            List<Attempt> attemptList = new List<Attempt>();

            IDataReader dataReader = attemptDao.ListForStudent(securityProvider.GetCurrentUserSession().UserId, new EditStatus(EditStatus.Published).ToValue());

            while (dataReader.Read())
            {
                Attempt attempt = GetAttempt(dataReader);

                attemptList.Add(attempt);

            }
            dataReader.Close();

            return attemptList;
        }

        public static List<Attempt> ListHistoryForStudent()
        {
            SecurityProvider securityProvider = new SecurityProvider();

            List<Attempt> attemptList = new List<Attempt>();

            IDataReader dataReader = attemptDao.ListHistoryForStudent(securityProvider.GetCurrentUserSession().UserId);

            while (dataReader.Read())
            {
                Attempt attempt = GetAttempt(dataReader);

                attemptList.Add(attempt);
            }
            dataReader.Close();

            return attemptList;
        }

        private static Attempt GetAttempt(IDataReader dataReader)
        {
            Attempt attempt = new Attempt();
            Attempt.FromDataReader(attempt, dataReader);

            attempt.Classroom.ClassroomName = DbUtils.ReadString(dataReader, "ClassroomName");
            attempt.Classroom.StartDate = DbUtils.ReadDate(dataReader, "ClassroomStartDate").Value;
            attempt.Classroom.EndDate = DbUtils.ReadDate(dataReader, "ClassroomEndDate").Value;
            attempt.Test.TestName = DbUtils.ReadString(dataReader, "TestName");
            attempt.Test.ResolutionMaxMinutes = DbUtils.ReadInt(dataReader, "ResolutionMaxMinutes");
            attempt.Test.MaxAttempts = DbUtils.ReadInt(dataReader, "MaxAttempts");
            attempt.Test.EvaluationType = EvaluationType.FromString((DbUtils.ReadString(dataReader, "EvaluationType")));

            return attempt;
        }

        public static int GetNumberOfAttempts(Test test, Classroom classroom, User user)
        {
            int numberOfAttempts = 0;

            IDataReader dataReader = attemptDao.GetNumberOfAttempts(test.TestId.Value, classroom.ClassroomId.Value, user.UserId.Value);

            if (dataReader.Read())
            {
                numberOfAttempts = DbUtils.ReadInt(dataReader, "NumberOfAttempts").Value;
            }
            dataReader.Close();

            return numberOfAttempts;
        }
    }
}
