﻿using System;
using System.Data.Common;
using System.Data;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Enums;
using AutoProofreader.Dao;
using AutoProofreader.Dao.SqlServer;
using AutoProofreader.Utils;
using AutoProofreader.Security;


namespace AutoProofreader.Managers
{
    public class ClassroomManager
    {
        private static IClassroomDAO classroomDao = DaoProvider.GetClassroomDao();

        public static List<Classroom> List()
        {
            List<Classroom> ClassroomList = new List<Classroom>();
            IDataReader dataReader = classroomDao.List();

            while (dataReader.Read())
            {
                Classroom Classroom = new Classroom();
                Classroom.FromDataReader(Classroom, dataReader);
                ClassroomList.Add(Classroom);
            }
            dataReader.Close();

            return ClassroomList;
        }

        public static List<Classroom> ListByUser(User user)
        {
            SecurityProvider securityProvider = new SecurityProvider();

            List<Classroom> ClassroomList = new List<Classroom>();

            IDataReader dataReader = classroomDao.ListByUserId(user.UserId.Value);

            while (dataReader.Read())
            {
                Classroom Classroom = new Classroom();
                Classroom.FromDataReader(Classroom, dataReader);
                ClassroomList.Add(Classroom);
            }
            dataReader.Close();

            return ClassroomList;
        }

        public static List<Classroom> ListByNotAssignedUser(User user)
        {
            List<Classroom> ClassroomList = new List<Classroom>();

            IDataReader dataReader = classroomDao.ListByNotAssignedToUserId(user.UserId.Value);

            while (dataReader.Read())
            {
                Classroom Classroom = new Classroom();
                Classroom.FromDataReader(Classroom, dataReader);
                ClassroomList.Add(Classroom);
            }
            dataReader.Close();

            return ClassroomList;
        }


        public static List<Classroom> ListByTest(Test test)
        {
            List<Classroom> ClassroomList = new List<Classroom>();

            IDataReader dataReader = classroomDao.ListByTestId(test.TestId.Value);

            while (dataReader.Read())
            {
                Classroom classroom = new Classroom();
                Classroom.FromDataReader(classroom, dataReader);

                classroom.TestStartDate= DbUtils.ReadDate(dataReader, "TestStartDate");
                classroom.TestEndDate = DbUtils.ReadDate(dataReader, "TestEndDate");
                ClassroomList.Add(classroom);
            }
            dataReader.Close();

            return ClassroomList;
        }

        public static List<Classroom> ListByNotAssignedToTest(Test test)
        {
            List<Classroom> ClassroomList = new List<Classroom>();

            IDataReader dataReader = classroomDao.ListByNotAssignedToTestId(test.TestId.Value);

            while (dataReader.Read())
            {
                Classroom classroom = new Classroom();
                Classroom.FromDataReader(classroom, dataReader);
                ClassroomList.Add(classroom);
            }
            dataReader.Close();

            return ClassroomList;
        }

        public static List<Classroom> Select(string searchText, bool isDeleted, User user, int startRowIndex, int maximumRows, string sortColumn, string sortDirection)
        {
            List<Classroom> ClassroomList = new List<Classroom>();

            long? userId = null;
            if (user != null) userId = user.UserId.Value;

            IDataReader dataReader = classroomDao.Select(searchText, isDeleted, userId,maximumRows, startRowIndex, sortColumn, sortDirection);
            
            while (dataReader.Read())
            {
                Classroom classroom = new Classroom();
                Classroom.FromDataReader(classroom, dataReader);
                classroom.StudentCount = DbUtils.ReadInt(dataReader, "StudentCount");
                classroom.TeacherCount = DbUtils.ReadInt(dataReader, "TeacherCount");
                ClassroomList.Add(classroom);
            }
            dataReader.Close();

            return ClassroomList;
        }

        public static int Count(string searchText, bool isDeleted, User user)
        {
            long? userId = null;
            if (user != null) userId = user.UserId.Value;

            return classroomDao.Count(searchText, isDeleted, userId);
        }

    }
}
