﻿using System;
using System.Data.Common;
using System.Data;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Enums;
using AutoProofreader.Exceptions;
using AutoProofreader.Dao;
using AutoProofreader.Dao.SqlServer;
using AutoProofreader.Utils;

namespace AutoProofreader.Managers
{
    public class QuestionManager
    {
        private static IQuestionDAO questionDao = DaoProvider.GetQuestionDao();

        public static List<Question> ListFromLibrary(Category category)
        {
            List<Question> questionList = new List<Question>();

            IDataReader dataReader = questionDao.ListByEditStatusCategoryId(new EditStatus(EditStatus.Published).ToValue(), category.CategoryId, null);

            while (dataReader.Read())
            {
                Question question = new Question();
                Question.FromDataReader(question, dataReader);
                questionList.Add(question);
            }
            dataReader.Close();

            return questionList;
        }


        public static List<Question> ListFromLibrary(Category category, Test test)
        {
            List<Question> questionList = new List<Question>();

            IDataReader dataReader = questionDao.ListByEditStatusCategoryId(new EditStatus(EditStatus.Published).ToValue(), category.CategoryId, test.TestId);

            while (dataReader.Read())
            {
                Question question = new Question();
                Question.FromDataReader(question, dataReader);
                questionList.Add(question);
            }
            dataReader.Close();

            return questionList;
        }

        public static List<Question> ListByTest(Test test)
        {
            List<Question> questionList = new List<Question>();

            IDataReader dataReader = questionDao.ListByTestId(test.TestId.Value);

            while (dataReader.Read())
            {
                Question question = new Question();

                question.TestQuestionId = DbUtils.ReadLong(dataReader, "TestQuestionId").Value;
                Question.FromDataReader(question, dataReader);

                if (question.QuestionType.Value == QuestionType.Random)
                {                    
                    Category.FromDataReader(question.Category, dataReader);
                }

                questionList.Add(question);
            }
            dataReader.Close();

            return questionList;
        }

        public static List<Question> ListByAttempt(Attempt attempt)
        {
            List<Question> questionList = new List<Question>();

            IDataReader dataReader = questionDao.ListByAttemptId(attempt.AttemptId.Value);

            Question currentQuestion = new Question();

            while (dataReader.Read())
            {
                Question question = new Question();
                Question.FromDataReader(question, dataReader);

                if (currentQuestion.QuestionId == null || currentQuestion.QuestionId.Value != question.QuestionId.Value)
                {
                    currentQuestion = question;
                    questionList.Add(question);
                }

                Answer answer= new Answer();
                Answer.FromDataReader(answer, dataReader);
                answer.AttemptValue = DbUtils.ReadString(dataReader, "AttemptValue");

                currentQuestion.AddAttemptAnswer(answer);                
            }
            dataReader.Close();

            return questionList;
        }



        public static List<Question> GenerateForTest(Test test)
        {
            List<Question> questionList = ListByTest(test);
            Hashtable htCategoryQuestions = new Hashtable();

            for (int i = 0; i < questionList.Count; i++)
            {
                Question question = questionList[i];

                if (question.QuestionType.Value == QuestionType.Random)
                {
                    //Replace random question by question from library

                    //Pick questions mapped to the category
                    List<Question> questionCategoryList;
                    if (!htCategoryQuestions.ContainsKey(question.Category.CategoryId))
                    {
                        questionCategoryList = QuestionManager.ListFromLibrary(question.Category);
                        htCategoryQuestions.Add(question.Category.CategoryId, questionCategoryList);
                    }
                    else
                    {
                        questionCategoryList = (List<Question>)htCategoryQuestions[question.Category.CategoryId];
                    }
                    if (questionCategoryList.Count > 0)
                    {
                        //Choose a random question from the list;
                        Random random = new Random();
                        int randomIndex = random.Next(0, questionCategoryList.Count - 1);

                        Question randomQuestion = questionCategoryList[randomIndex];
                        questionCategoryList.RemoveAt(randomIndex);

                        //Replace random question by choosen question
                        questionList[i] = randomQuestion;
                    }
                    else
                    {
                        //in theory, this can't ever happen because we have already checked that there are available questions on the choosen category when adding the random question to the test
                        throw new BusinessLogicException(string.Format("No s'ha trovat cap pregunta publicada amb la categoria {0}", question.Category.CategoryName));
                    }
                }

            }

            return questionList;
        }
    }
}
