﻿using System;
using System.Data.Common;
using System.Data;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Enums;
using AutoProofreader.Dao;
using AutoProofreader.Dao.SqlServer;
using AutoProofreader.Utils;

namespace AutoProofreader.Managers
{
    public class UserManager
    {
        private static IUserDAO userDao = DaoProvider.GetUserDao();

        public static List<User> List()
        {
            List<User> userList = new List<User>();            
            IDataReader dataReader = userDao.List();

            while (dataReader.Read())
            {
                User user = new User();
                User.FromDataReader(user, dataReader);
                userList.Add(user);
            }
            dataReader.Close();

            return userList;
        }

        public static List<User> ListByClassroom(Classroom classroom)
        {
            List<User> userList = new List<User>();

            IDataReader dataReader = userDao.ListByClassroomId(classroom.ClassroomId.Value);

            while (dataReader.Read())
            {
                User user = new User();
                User.FromDataReader(user, dataReader);
                userList.Add(user);
            }
            dataReader.Close();

            return userList;
        }

        public static List<User> ListNotInClassroom(Classroom classroom)
        {
            List<User> userList = new List<User>();

            IDataReader dataReader = userDao.ListByNotClassroomId(classroom.ClassroomId.Value);

            while (dataReader.Read())
            {
                User user = new User();
                User.FromDataReader(user, dataReader);
                userList.Add(user);
            }
            dataReader.Close();

            return userList;
        }

        public static List<User> Select(string searchText, UserType userType, bool isDeleted, Classroom classroom, int startRowIndex, int maximumRows, string sortColumn, string sortDirection)
        {
            List<User> userList = new List<User>();

            long? classroomId = null;
            if (classroom != null) classroomId = classroom.ClassroomId.Value;

            IDataReader dataReader = userDao.Select(searchText, UserType.ToValue(userType), isDeleted, classroomId, maximumRows, startRowIndex, sortColumn, sortDirection);
            
            while (dataReader.Read())
            {
                User user = new User();
                User.FromDataReader(user, dataReader);
                userList.Add(user);
            }
            dataReader.Close();

            return userList;
        }

        public static int Count(string searchText, UserType userType, bool isDeleted, Classroom classroom)
        {
            long? classroomId = null;
            if (classroom != null) classroomId = classroom.ClassroomId.Value;

            return userDao.Count(searchText, UserType.ToValue(userType), isDeleted, classroomId);
        }

    }
}
