﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Web;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Exceptions;
using AutoProofreader.Enums;

namespace AutoProofreader.Security
{
    /// <summary>
    /// Security provider.
    /// It uses HttpContext session to manage session on web environments.
    /// On non-web environments such as unit tests, it handles a single session using a static dictionary
    /// </summary>
    public class SecurityProvider
    {
        private static Dictionary<string, object> localSession = new Dictionary<string,object>();

        private const string USER_SESSION_KEY= "UserSession";
        private const int PASSWORD_LENGTH = 6;
        private UserSession userSession;

        public SecurityProvider()
        {
            if (HttpContext.Current != null)
            {
                this.userSession = (UserSession)HttpContext.Current.Session[USER_SESSION_KEY];
            }
            else
            {
                if (localSession.ContainsKey(USER_SESSION_KEY))
                {
                    this.userSession = (UserSession)localSession[USER_SESSION_KEY];
                }
            }
            
        }

        public UserSession GetCurrentUserSession() 
        {
            return this.userSession;
        }

        public void CheckUserType(UserType userType)
        {
            if (! IsUserType(userType))
            {
                throw new BusinessLogicException("No tens permís per realitzar aquesta operació.");
            }
        }

        public bool IsUserType(UserType userType)
        {
            if (this.userSession != null)
            {
                return this.userSession.UserType.Value == userType.Value;
            }
            return false;
        }

        public static UserSession Login(string userName, string password)
        {
            if (!string.IsNullOrEmpty(userName) && !string.IsNullOrEmpty(password))
            {
                string encryptedPassword = CryptoProvider.Encrypt(password);
                User user = new User();
                if (user.Load(userName, encryptedPassword))
                {
                    UserSession userSession = new UserSession(user);

                    if (HttpContext.Current != null)
                    {
                        HttpContext.Current.Session.Add(USER_SESSION_KEY, userSession);
                    }
                    else
                    {
                        localSession.Add(USER_SESSION_KEY, userSession);
                    }

                    Log.Add("L'usuari ha iniciat sessió");

                    return userSession;
                }
            }
            throw new SecurityException("Usuari o contrasenya no vàlids");
        }

        public static string GenerateRandomPassword()
        {
            string allowedChars = "abcdefghijkmnopqrstuvwxyzABCDEFGHJKLMNOPQRSTUVWXYZ0123456789";
            char[] chars = new char[PASSWORD_LENGTH];
            Random rd = new Random();

            for (int i = 0; i < PASSWORD_LENGTH; i++)
            {
                chars[i] = allowedChars[rd.Next(0, allowedChars.Length)];
            }

            return new string(chars);
        }
    }
}
