﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Enums;
using AutoProofreader.Exceptions;
using AutoProofreader.Managers;
using AutoProofreader.Utils;
using AutoProofreader.UI;

namespace Web.Admin
{
    public partial class EditCategory : EditPageBase
    {
        /// <summary>
        /// Security page check based on user type 
        /// </summary>
        protected override UserType pageUserType
        {
            get { return new UserType(UserType.Administrator); }
        }


        protected Category category;
        protected string pageTitle;


        protected override void InitData()
        {
            category = new Category();
            category.CategoryId = TypeUtils.ToLong(Request.QueryString["CategoryId"]);            
        }

        protected override void LoadData()
        {
            category.Load();          
        }

        protected override void LoadControls()
        {
            FillCategoryControls();
        }

        protected void BtnSaveCategory_Click(object sender, EventArgs e)
        {
            try
            {
                category.CategoryName = txt_CategoryName.Text;
                category.IsDeleted = chk_isDeleted.Checked;
                category.Save();

                //Show feedback
                this.userFeedback.ShowInfo("Categoria guardada.");

                //Update header
                this.pnl_Header.Update();
            }
            catch (BusinessLogicException ble)
            {
                userFeedback.ShowWarning(ble.Message);
            }
            catch (Exception ble)
            {
                userFeedback.ShowError(ble.Message);
            }

            //Reload controls
            LoadControls();
        }

        private void FillCategoryControls()
        {
            txt_CategoryName.Text = category.CategoryName;
            chk_isDeleted.Checked = category.IsDeleted;

            if (category.Exists())
            {
                pageTitle = category.CategoryName;
                this.chk_isDeleted.Visible = true;
            }
            else
            {
                pageTitle = "Nova categoria";
                this.chk_isDeleted.Visible = false;
            }

        }
    }
}