﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Enums;
using AutoProofreader.Exceptions;
using AutoProofreader.Managers;
using AutoProofreader.Utils;
using AutoProofreader.UI;

namespace Web.Admin
{
    public partial class EditClassroom : EditPageBase
    {
        /// <summary>
        /// Security page check based on user type 
        /// </summary>
        protected override UserType pageUserType
        {
            get { return new UserType(UserType.Administrator); }
        }

        protected Classroom classroom;
        protected string pageTitle;

        private long? SelectedClassroomId
        {
            get
            {
                long? SelectedClassroomId = TypeUtils.ToLong(Request.QueryString["ClassroomId"]);
                if (!SelectedClassroomId.HasValue)
                {
                    SelectedClassroomId = TypeUtils.ToLong(ViewState["SelectedClassroomId"]);
                }
                return SelectedClassroomId;
            }
            set
            {
                ViewState["SelectedClassroomId"] = value;
            }
        }

        protected override void InitData()
        {
            classroom = new Classroom();
            classroom.ClassroomId = SelectedClassroomId;
        }

        protected override void LoadData()
        {
            classroom.Load();
        }

        protected override void LoadControls()
        {
            gv_UserList.AllowPaging = false;
            gv_UserList.AllowSorting = false;

            if (classroom.Exists())
            {
                FillClassroomControls();

                menuClassroom.ShowOnlyFirstMenuItem = false;

                this.chk_isDeleted.Visible = true;
            }
            else
            {
                pageTitle = "Nova aula";

                menuClassroom.ShowOnlyFirstMenuItem = true;

                this.chk_isDeleted.Visible = false;
            }
        }


        protected void BtnSaveClassroom_Click(object sender, EventArgs e)
        {
            try
            {
                classroom.ClassroomName = txt_ClassroomName.Text;
                classroom.StartDate = txt_StartDate.GetDateTime();
                classroom.EndDate = txt_EndDate.GetDateTime();
                classroom.IsDeleted = chk_isDeleted.Checked;
                classroom.Save();

                //Update selected classroom
                SelectedClassroomId = classroom.ClassroomId;

                //Show feedback
                this.userFeedback.ShowInfo("Aula guardada.");

                //Update header
                this.pnl_Header.Update();
            }
            catch (BusinessLogicException ble)
            {
                userFeedback.ShowWarning(ble.Message);
            }
            catch (Exception ble)
            {
                userFeedback.ShowError(ble.Message);
            }
            //Reload controls
            LoadControls();
        }

        public IQueryable<User> ddl_User_GetData()
        {
            if (classroom.Exists())
            {
                return UserManager.ListNotInClassroom(classroom).AsQueryable();
            }
            else
            {
                return UserManager.List().AsQueryable();
            }
        }

        protected void gv_User_RowDataBound(object sender, GridViewRowEventArgs e)
        {

        }

        public IQueryable<User> gv_User_GetData()
        {
            if (classroom.Exists())
            {
                return UserManager.ListByClassroom(classroom).AsQueryable();
            }
            else
            {
                return new List<User>().AsQueryable();
            }
        }

        public void gv_User_Delete(User user)
        {
            if (user != null)
            {

                BindClassroomUsers();
            }
        }

        protected void gv_User_RowCommand(object sender, GridViewCommandEventArgs e)
        {
            long? userId = TypeUtils.ToLong(e.CommandArgument);

            if (userId.HasValue)
            {
                if (e.CommandName == "remove")
                {
                    User user = new User();
                    user.UserId = userId;
                    classroom.UnassignUser(user);
                    BindClassroomUsers();
                }
            }
        }

        protected void btn_assignUser_Click(object sender, EventArgs e)
        {
            User user = new User();
            user.UserId = TypeUtils.ToLong(this.ddl_User.SelectedValue);

            if (user.Exists() && user.Load())
            {
                classroom.AssignUser(user);
            }
            BindClassroomUsers();
        }


        private void BindClassroomUsers()
        {
            this.gv_UserList.DataBind();
            this.ddl_User.Items.Clear();
            this.ddl_User.DataBind();
        }

        private void FillClassroomControls()
        {
            txt_ClassroomName.Text = classroom.ClassroomName;
            txt_StartDate.SetDateTime(classroom.StartDate);
            txt_EndDate.SetDateTime(classroom.EndDate);
            chk_isDeleted.Checked = classroom.IsDeleted;

            pageTitle = classroom.ClassroomName;
        }




        protected override void OnDataBinding(EventArgs e)
        {
            base.OnDataBinding(e);

            if (this.ddl_User.Items.Count == 0)
            {
                this.btn_assignUser.Visible = false;
            }
        }
    }
}