﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Enums;
using AutoProofreader.Exceptions;
using AutoProofreader.Managers;
using AutoProofreader.Utils;
using AutoProofreader.UI;

namespace Web.Admin
{
    public partial class EditUser : EditPageBase
    {
        /// <summary>
        /// Security page check based on user type 
        /// </summary>
        protected override UserType pageUserType
        {
            get { return new UserType(UserType.Administrator); }
        }


        protected User user;
        protected string pageTitle;

        private long? SelectedUserId
        {
            get
            {
                long? selectedUserId = TypeUtils.ToLong(Request.QueryString["UserId"]);
                if (!selectedUserId.HasValue)
                {
                    selectedUserId = TypeUtils.ToLong(ViewState["SelectedUserId"]);
                }
                return selectedUserId;
            }
            set
            {
                ViewState["SelectedUserId"] = value;
            }
        }

        protected override void InitData()
        {
            user = new User();
            user.UserId = SelectedUserId;            
        }

        protected override void LoadData()
        {
            user.Load();
        
        }

        protected override void LoadControls()
        {
            if (user.Exists())
            {
                btnResetPassword.Visible = true;

                FillUserControls();

                menuUser.ShowOnlyFirstMenuItem = false;

                this.chk_isDeleted.Visible = true;
            }
            else
            {
                btnResetPassword.Visible = false;

                menuUser.ShowOnlyFirstMenuItem = true;

                pageTitle = "Nou usuari";

                this.chk_isDeleted.Visible = false;
            }
        }

        protected override void OnLoad(EventArgs e)
        {
            gv_Log.AllowSorting = false;
            gv_Classroom.AllowPaging = false;
            gv_Classroom.AllowSorting = false;

            base.OnLoad(e);
        }

        protected void BtnSaveUser_Click(object sender, EventArgs e)
        {
            try
            {
                bool exist = user.Exists();

                user.FirstName = txt_FirstName.Text;
                user.LastName = txt_LastName.Text;
                user.UserName = txt_UserName.Text;
                user.IsDeleted = chk_isDeleted.Checked;
                user.UserType = UserType.FromString(ddl_UserType.SelectedValue);
                user.Save();

                //Update selected user
                SelectedUserId = user.UserId;

               //Show feedback
                string feedbackInfo = "Usuari guardat.";
                if (! exist)
                {
                    feedbackInfo += string.Format("<br/> S'ha enviat un correu electrònic a l'adreça de l'usuari {0} amb la seva contrasenya", user.UserName);
                }

                this.userFeedback.ShowInfo(feedbackInfo);

                //Update header
                this.pnl_Header.Update();
            }
            catch (BusinessLogicException ble) 
            {                
                this.userFeedback.ShowWarning(ble.Message);
            }
            catch (Exception ex)
            {
                this.userFeedback.ShowError(ex.Message);
            }

            //Reload controls
            LoadControls();
        }

          
        public List<Log> gv_Log_GetData(int maximumRows, int startRowIndex, out int totalRowCount)
        {
            if (user.Exists())
            {
                totalRowCount = LogManager.Count(user, null, null, new LogType(LogType.Info));
                return LogManager.Select(user, null, null, new LogType(LogType.Info), startRowIndex, maximumRows);
            }
            else
            {
                totalRowCount = 0;
                return new List<Log>();
            }
        }

        public IQueryable<Classroom> ddl_Classroom_GetData()
        {
            if (user.Exists())
            {
                return ClassroomManager.ListByNotAssignedUser(user).AsQueryable();
            }
            else
            {
                return ClassroomManager.List().AsQueryable();
            }
        }

        protected void gv_Classroom_RowCommand(object sender, GridViewCommandEventArgs e)
        {
            long? classroomId= TypeUtils.ToLong(e.CommandArgument);

            if (classroomId.HasValue)
            {
                if (e.CommandName == "remove")
                {
                    Classroom classroom = new Classroom();
                    classroom.ClassroomId = classroomId;

                    classroom.UnassignUser(user);
                    BindClassroomUsers();
                }
            }
        }


        protected void gv_Classroom_RowDataBound(object sender, GridViewRowEventArgs e)
        {

        }

        public IQueryable<Classroom> gv_Classroom_GetData()
        {
            if (user.Exists())
            {
                return ClassroomManager.ListByUser(user).AsQueryable();
            }
            else
            {
                return new List<Classroom>().AsQueryable();
            }
        }


        protected void btn_assignClassroom_Click(object sender, EventArgs e)
        {
            Classroom classroom = new Classroom();
            classroom.ClassroomId= TypeUtils.ToLong(this.ddl_Classroom.SelectedValue);

            if (classroom.Exists() && classroom.Load())
            {
                classroom.AssignUser(user);
                BindClassroomUsers();
            }
        }

        private void FillUserControls()
        {
            txt_FirstName.Text = user.FirstName;
            txt_LastName.Text = user.LastName;
            txt_UserName.Text = user.UserName;
            ddl_UserType.SelectedValue = user.UserType.ToValue();
            chk_isDeleted.Checked = user.IsDeleted;

            pageTitle = user.FirstName + " " + user.LastName;
        }

        private void BindClassroomUsers()
        {
            this.gv_Classroom.DataBind();
            this.ddl_Classroom.Items.Clear();
            this.ddl_Classroom.DataBind();
        }

        protected void btnResetPassword_Click(object sender, EventArgs e)
        {
            try
            {
                if (user.Exists())
                {
                    user.Load();
                    user.ResetPassword();
                    userFeedback.ShowWarning(string.Format("S'ha enviat un correu electrònic a l'adreça de l'usuari {0} amb la nova contrasenya", user.UserName));
                }                

            }
            catch (Exception)
            {
                userFeedback.ShowError("Error enviat correu electrònic");
            }  
        }



        protected override void OnDataBinding(EventArgs e)
        {
            base.OnDataBinding(e);

            if (this.ddl_Classroom.Items.Count == 0)
            {
                this.btn_assignClassroom.Visible = false;
            }
        }
    }
}