﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Exceptions;
using AutoProofreader.Enums;
using AutoProofreader.Managers;
using AutoProofreader.UI;
using AutoProofreader.UI.WebControls;
using AutoProofreader.Utils;

namespace Web.Controls
{
    public partial class TestControl : System.Web.UI.UserControl
    {
        protected Attempt attempt = new Attempt();
        private List<AprQuestion> questionControlList = new List<AprQuestion>();
        private List<Question> currentQuestions = new List<Question>();
        public bool IsPreview = false;
        private bool canAccessTest = true;

        protected override void OnInit(EventArgs e)
        {
            questionControlList = new List<AprQuestion>();
            currentQuestions = new List<Question>();

            attempt = new Attempt();
            attempt.AttemptId = TypeUtils.ToLong(Request.QueryString["AttemptId"]);
            attempt.Test = new Test();
            attempt.Test.TestId = TypeUtils.ToLong(Request.QueryString["TestId"]);
            attempt.Classroom = new Classroom();
            attempt.Classroom.ClassroomId = TypeUtils.ToLong(Request.QueryString["ClassroomId"]);
            attempt.User = new User();
            attempt.User.UserId= ((PageBase) this.Page).securityProvider.GetCurrentUserSession().UserId;

            InitPage();

            base.OnInit(e);
        }

        private void InitPage()
        {
            if (!Page.IsPostBack)
            {                  
                if (attempt.Exists())
                {
                    attempt.Load();

                    if (attempt.HasExpired())
                    {
                        this.pnl_RemainingTime.Visible = false;
                        this.pnl_Result.Visible = true;
                    }

                    Session.Add("Attempt", attempt);
                }
                else
                {
                    if (attempt.Test.Load(true))
                    {
                        lit_Description.Text = attempt.Test.TestDescription;
                        lb_ResolutionMaxMinutes.Text = TypeUtils.ToString(attempt.Test.ResolutionMaxMinutes);
                        lb_QuestionsCount.Text = attempt.Test.QuestionList.Count.ToString();
                    }
                    canAccessTest = ! attempt.HasExceedeedNumberOfAttempts();
                    if (!canAccessTest)
                    {
                        ShowErrorAndClose("Ja has relitzat el nombre màxim d'intents per aquesta prova.");
                    }
                    else
                    {
                        attempt.Test.GenerateQuestions();
                        Session.Add("Attempt", attempt);
                    }
                }                
            }
            else
            {
                attempt = (Attempt)Session["Attempt"];
                if (attempt == null) throw new Exception("No s'ha trovat l'intent en la sessió");
            }
        
            lb_TestTitle.Text = attempt.Test.TestName;

            AddQuestionsToWizard();
        }

        private void ShowErrorAndClose(string message)
        {
            string js = "";
            js += string.Format("<script language=\"javascript\">alert(\"{0}\"); this.close();</script>", message);
            Response.Write(js);
            Response.Flush();
            Response.End();
        }

        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);
        }

        private void AddQuestionsToWizard()
        {
            int stepCount = 1;

            WizardStep wizardStep = GetWizardStep();
            float questionNumber = 0;
            float questionsPerPage = attempt.Test.QuestionsPerPage.Value;
            float questionsPerPageNumber = 1;

            foreach (Question question in attempt.Test.QuestionList)
            {
                if (question.Exists())
                {
                    AprQuestion aprQuestion = new AprQuestion((int)questionNumber + 1, question);
                    questionControlList.Add(aprQuestion);

                    if (questionsPerPageNumber == questionsPerPage)
                    {
                        wizardStep.Controls.Add(aprQuestion);

                        this.wz_Test.WizardSteps.AddAt(stepCount, wizardStep);
                        stepCount++;
                        wizardStep = GetWizardStep();
                        questionsPerPageNumber = 0;
                    }
                    else
                    {
                        wizardStep.Controls.Add(aprQuestion);
                    }

                    questionNumber++;
                    questionsPerPageNumber++;
                }
            }

            //this.wz_Test.WizardSteps.AddAt(stepCount, wizardStep);
            this.wz_Test.WizardSteps[this.wz_Test.WizardSteps.Count - 1].StepType = WizardStepType.Finish;

            //Skip start
            if (!Page.IsPostBack && attempt.Exists() && (
                (attempt.HasExpired() || attempt.IsStillGoingOn)))
            {
                this.wz_Test.MoveTo(this.wz_Test.WizardSteps[1]);

                if (this.attempt.IsStillGoingOn && this.attempt.Test.ResolutionMaxMinutes.HasValue)
                {
                    this.pnl_RemainingTime.Visible = true;
                    UpdateJsCounter((int)
                        (new TimeSpan(0, this.attempt.Test.ResolutionMaxMinutes.Value, 0).TotalMilliseconds - 
                        (DateTime.Now - this.attempt.StartDate.Value).TotalMilliseconds));
                }
            }
        }

        private WizardStep GetWizardStep()
        {
            WizardStep wizardStep = new WizardStep();
            wizardStep.StepType = WizardStepType.Step;
            return wizardStep;
        }

        private void DisablePreviousButton()
        {
            if (this.wz_Test.ActiveStep.StepType != WizardStepType.Finish)
            {
                ((Button)this.wz_Test.FindControl("StepNavigationTemplateContainerID$BtnPrevious")).Visible = true;

                int index = this.wz_Test.ActiveStepIndex;
                if (index == 0 || this.wz_Test.WizardSteps[index - 1].StepType == WizardStepType.Start)
                {
                    ((Button)this.wz_Test.FindControl("StepNavigationTemplateContainerID$BtnPrevious")).Visible = false;
                }
            }
            else
            {
                ((Button)this.wz_Test.FindControl("FinishNavigationTemplateContainerID$FinishPreviousButton")).Visible = true;

                int index = this.wz_Test.ActiveStepIndex;
                if (index == 0 || this.wz_Test.WizardSteps[index - 1].StepType == WizardStepType.Start)
                {
                    ((Button)this.wz_Test.FindControl("FinishNavigationTemplateContainerID$FinishPreviousButton")).Visible = false;
                }
            }
        }

        private void DisableFinishButton()
        {
            if (attempt.HasExpired() && this.wz_Test.ActiveStep.StepType == WizardStepType.Finish)
            {
                ((Button)this.wz_Test.FindControl("FinishNavigationTemplateContainerID$FinishButton")).Visible = false;
            }
            
        }

        protected override void OnPreRender(EventArgs e)
        {
            if (canAccessTest)
            {
                DisableFinishButton();
                DisablePreviousButton();

                if (!Page.IsPostBack && attempt.Exists() && attempt.HasExpired())
                {
                    CorrectUIQuestions();
                }
                if (Page.IsPostBack && 
                    this.wz_Test.ActiveStepIndex == 1 && 
                    ! attempt.HasExpired() && 
                    attempt.Classroom.Exists())
                {
                    RefreshOpener();           
                }
            }

            base.OnPreRender(e);
        }

        private void RefreshOpener()
        {
            ScriptManager.RegisterStartupScript(this.Page, this.Page.GetType(), "refresh", "refreshOpener();", true);
        }

        protected void wz_Test_FinishButtonClick(object sender, WizardNavigationEventArgs e)
        {
            FinishTest();

            DisableFinishButton();

            if (this.attempt.Classroom.Exists())
            {
                RefreshOpener();
            }
        }

        protected void wz_Test_NextButtonClick(object sender, WizardNavigationEventArgs e)
        {
            if (e.CurrentStepIndex == 0) //starting the test 
            {
                if (!attempt.Exists())
                {
                    this.pnl_RemainingTime.Visible = true;

                    attempt.Start();
                    Session.Add("Attempt", attempt);

                    if (attempt.Test.ResolutionMaxMinutes.HasValue)
                    {
                        this.lb_RemainingTime.Text = "";
                        UpdateJsCounter((int) new TimeSpan(0, attempt.Test.ResolutionMaxMinutes.Value, 0).TotalMilliseconds);
                    }
                }
                
                //Display results
                this.pnl_RemainingTime.Visible = true;
                this.pnl_Result.Visible = false;

                pnl_AttemptInfo.Update();                
            }
            else
            {
                UpdateAttemptValues();
            }
        }

        private void UpdateJsCounter(int miliseconds) {

            string js= "$(function () { " +
                "$('#"  + this.lb_RemainingTime.ClientID + "').countdown(new Date(new Date().getTime() + " + miliseconds.ToString()  + ")) "+ 
                ".on('update.countdown', function (event) {" + 
                "    var format = '%H:%M:%S';" +                       
                "    $(this).html(event.strftime(format));" +
                "})" + 
                ".on('finish.countdown', function (event) {" +
                "    $('#btnExpired').click(); " +
                "  });"+
                "});";
            ScriptManager.RegisterStartupScript(this.Page, this.Page.GetType(), "startCounter", js, true);
        }

        private void FinishTest()
        {
            //Update last step
            UpdateAttemptValues();

            //Stop attempt
            attempt.Stop();

            //Correct ui questions
            CorrectUIQuestions();

            //Display results
            this.pnl_RemainingTime.Visible = false;
            this.pnl_Result.Visible = true;

            this.pnl_AttemptInfo.Update();
        }

        protected override void Render(HtmlTextWriter writer)
        {
            base.Render(writer);
        }


        private void CorrectUIQuestions()
        {
            //Get score
            lb_Result.Text = attempt.Score;

            //Set up feedback
            this.wz_Test.MoveTo(this.wz_Test.WizardSteps[1]);

            //Correct UI questions
            foreach (AprQuestion aprQuestion in questionControlList)
            {
                aprQuestion.Correct();
            }
        }
        private void UpdateAttemptValues()
        {
            foreach (AprQuestion aprQuestion in questionControlList)
            {
                aprQuestion.UpdateAttemptValues(); //Update current attempt with inputted values
            }
            if (!IsPreview && attempt.IsStillGoingOn)
            {
                //Update attempt on DB
                attempt.UpdateAttemptQuestionAnswer();
            }
        }

        protected void btnExpired_Click(object sender, EventArgs e)
        {
            FinishTest();
        }     
    }
}