﻿using System;
using System.Diagnostics;
using System.Web;

namespace Web
{
    /// <summary>
    /// Meassures page execution timing before and after processing the request.
    /// This doesn't apply to Ajax calls on UpdatePanels, as the output message would break the panel's rendering
    /// </summary>
    public class PageTimingModule : IHttpModule
    {
        public void Dispose()
        {
        }

        public void Init(HttpApplication context)
        {
            context.BeginRequest += OnBeginRequest;
            context.EndRequest += OnEndRequest;
        }

        void OnBeginRequest(object sender, System.EventArgs e)
        {
            if (HttpContext.Current.Request.IsLocal && IsAspxPage() && ! IsAjax())
            {
                var stopwatch = new Stopwatch();
                HttpContext.Current.Items["Stopwatch"] = stopwatch;
                stopwatch.Start();
            }
        }

        void OnEndRequest(object sender, System.EventArgs e)
        {
            if (HttpContext.Current.Request.IsLocal && IsAspxPage() && !IsAjax())
            {
                Stopwatch stopwatch = (Stopwatch)HttpContext.Current.Items["Stopwatch"];
                stopwatch.Stop();

                TimeSpan ts = stopwatch.Elapsed;

                HttpContext.Current.Response.Write(string.Format("<!-- Pàgina generada en {0} segons -->", (ts.TotalSeconds).ToString("0.##")));
            }
        }

        private bool IsAspxPage()
        {
            string filePath = HttpContext.Current.Request.FilePath;
            string fileExtension = VirtualPathUtility.GetExtension(filePath);

            return fileExtension.Equals(".aspx");
        }

        private bool IsAjax()
        {
            return HttpContext.Current.Request.Headers["X-Requested-With"] != null;
        }
    }
}