﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Enums;
using AutoProofreader.Exceptions;
using AutoProofreader.Managers;
using AutoProofreader.Utils;
using AutoProofreader.UI;

namespace Web.Teacher
{
    public partial class EditQuestion : EditPageBase
    {
        /// <summary>
        /// Security page check based on user type 
        /// </summary>
        protected override UserType pageUserType
        {
            get { return new UserType(UserType.Teacher); }
        }

        protected Test test;
        protected Question question;
        protected Answer answer;
        protected string pageTitle;

        private long? SelectedTestId
        {
            get 
            {
                long? selectedTestId = TypeUtils.ToLong(Request.QueryString["TestId"]);
                if (!selectedTestId.HasValue)
                {
                    selectedTestId = TypeUtils.ToLong(ViewState["TestId"]);
                }
                return selectedTestId;
            }
            set
            {
                ViewState["TestId"] = value;
            }
        }

        private long? SelectedQuestionId
        {
            get
            {
                long? selectedQuestionId = TypeUtils.ToLong(Request.QueryString["QuestionId"]);
                if (!selectedQuestionId.HasValue)
                {
                    selectedQuestionId = TypeUtils.ToLong(ViewState["QuestionId"]);
                }
                return selectedQuestionId;
            }
            set
            {
                ViewState["QuestionId"] = value;
            }
        }

        private int? SelectedAnswerNumber
        {
            get
            {
                return TypeUtils.ToInt(ViewState["AnswerNumber"]);
            }
            set
            {
                ViewState["AnswerNumber"] = value;
            }

        }

        protected override void InitData()
        {
            test = new Test();
            question = new Question();
            answer = new Answer();

            test.TestId = SelectedTestId;
            question.QuestionId = SelectedQuestionId;

            if (Page.IsPostBack)
            {
                test.Load();
                question.Load();

                if (SelectedAnswerNumber.HasValue)
                {
                    answer.Question = question;
                    answer.AnswerNumber = SelectedAnswerNumber;
                    answer.Load();
                }
            }

            SetUploadForm();
        }

        private void SetUploadForm()
        {
            Page.Form.Attributes.Add("enctype", "multipart/form-data");

            /*
            PostBackTrigger postBackTrigger = new PostBackTrigger();
            postBackTrigger.ControlID = this.btn_SaveQuestion.ID;

            PostBackTrigger postBackTrigger1 = new PostBackTrigger();
            postBackTrigger1.ControlID = this.BtnSaveAnswer.ID;

            PostBackTrigger postBackTrigger2 = new PostBackTrigger();
            postBackTrigger2.ControlID = this.BtnSaveMultimedia.ID;

            this.menu_Pregunta.MenuItems[0].UpdatePanel.Triggers.Add(postBackTrigger);
            this.menu_Pregunta.MenuItems[1].UpdatePanel.Triggers.Add(postBackTrigger1);
            this.menu_Pregunta.MenuItems[2].UpdatePanel.Triggers.Add(postBackTrigger2);
             */
            ScriptManager.GetCurrent(this).RegisterPostBackControl(this.BtnSaveMultimedia);
        }

        protected override void LoadData()
        {            
            test.Load();            
            question.Load();

            if (question.Exists() && question.AnswersType.Value == AnswersType.FreeText)
            {
                SelectedAnswerNumber = 1;
            }

            if (SelectedAnswerNumber.HasValue)
            {
                answer.Question = question;
                answer.AnswerNumber = SelectedAnswerNumber;
                if (!answer.Load() && question.AnswersType.Value == AnswersType.FreeText)
                {
                    SelectedAnswerNumber = null;
                }


            }         
        }
 
        protected override void LoadControls()
        {
            FillQuestionControls();

            if (question.Exists())
            {
                btn_Preview.Visible = true;
                btn_Preview.OnClientClick = string.Format("javascript: previewQuestion({0}); return false;", question.QuestionId.Value);

                menu_Pregunta.ShowOnlyFirstMenuItem = false;

                if (question.AnswersType.Value == AnswersType.FreeText)
                {
                    pnl_AnswerFreeText.Visible = true;
                    pnl_Answer.Visible = false;
                    this.gv_Answers.Visible = false;
                }
                else
                {
                    pnl_AnswerFreeText.Visible = false;
                    pnl_Answer.Visible = true;
                    this.gv_Answers.Visible = true;
                }

                FillAnswerControls();

                if (answer.Exists() && question.AnswersType.Value != AnswersType.FreeText)
                {
                    this.BtnDeleteAnswer.Visible = true;
                }
                else
                {
                    this.BtnDeleteAnswer.Visible = false;
                }

                if (question.EditStatus.Value == EditStatus.Published)
                {
                    this.btn_SaveQuestion.Visible = false;
                    this.BtnDeleteAnswer.Visible = false;
                    this.BtnSaveAnswer.Visible = false;
                    this.BtnSaveAnswerFreeText.Visible = false;
                    this.BtnSaveMultimedia.Visible = false;
                }

                pageTitle = question.ShortQuestionDescription;

                DisplayMultimedia();
            }
            else
            {
                pageTitle = "Nova pregunta";
                menu_Pregunta.ShowOnlyFirstMenuItem = true;
                BtnDeleteAnswer.Visible = false;
            }
        }

        private void DisplayMultimedia()
        {
            string imagePath = question.GetImagePath();
            if (! string.IsNullOrEmpty(imagePath))
            {
                imgQuestion.ImageUrl = imagePath;
                pnl_imgQuestion.Visible = true;
            }
            else
            {
                pnl_imgQuestion.Visible = false;
            }

            string soundPath= question.GetSoundPath();
            if (!string.IsNullOrEmpty(soundPath))
            {
                soundQuestion.SoundUrl = soundPath; 
                pnl_soundQuestion.Visible = true;
            }
            else
            {
                pnl_soundQuestion.Visible = false;
            }
        }


        protected override void OnPreRender(EventArgs e)
        {
            base.OnPreRender(e);
        }

        protected void BtnSaveQuestion_Click(object sender, EventArgs e)
        {
            try
            {
                //Create the question
                question.QuestionDescription = txt_QuestionDescription.Text;
                question.AnswersType = AnswersType.FromString(ddl_AnswersType.SelectedValue);
                question.Category.CategoryId = TypeUtils.ToLong(ddl_Category.SelectedValue);
                question.SortOrder = 0;
                question.Save(test);

                //Update selected question
                SelectedQuestionId = question.QuestionId;

                //Reload controls
                LoadControls();

                //Show feedback
                this.userFeedback.ShowInfo("Pregunta guardada.");

                //Update header
                this.pnl_Header.Update();
            }
            catch (BusinessLogicException ble)
            {
                userFeedback.ShowWarning(ble.Message);
            }
            catch (Exception ble)
            {
                userFeedback.ShowError(ble.Message);
            }        
        }

        protected void BtnSaveAnswer_Click(object sender, EventArgs e)
        {
            try
            {
                bool adding = ! answer.Exists();
                answer.Question = question;
                answer.AnswerNumber = TypeUtils.ToInt(SelectedAnswerNumber);

                if (question.AnswersType.Value == AnswersType.FreeText)
                {
                    answer.AnswerDescription = "";
                    answer.IsCorrectHint = txt_FreeText_IsCorrectHint.Text;
                    answer.IsIncorrectHint = txt_FreeText_IsIncorrectHint.Text;
                    answer.CorrectValue = txt_CorrectValue.Text;
                }
                else
                {
                    answer.AnswerDescription = txt_AnswerDescription.Text;
                    answer.IsCorrectHint = txt_IsCorrectHint.Text;
                    answer.IsIncorrectHint = txt_IsIncorrectHint.Text;
                    answer.CorrectValue = chk_IsCorrectAnswer.Checked.ToString();
                }

                answer.Save();

                if (question.AnswersType.Value != AnswersType.FreeText)
                {
                    SelectedAnswerNumber = null;
                    answer.AnswerNumber = null;

                    if (adding)
                    {
                        answer = new Answer();
                    }

                    this.gv_Answers.DataBind();
                }
                else
                {
                    SelectedAnswerNumber = answer.AnswerNumber;
                }

                LoadControls();
                menu_Pregunta.SelectedIndex = 1;

                //Show feedback
                this.userFeedbackAnswer.ShowInfo("Resposta guardada.");
            }
            catch (BusinessLogicException ble)
            {
                userFeedbackAnswer.ShowWarning(ble.Message);
            }
            catch (Exception ble)
            {
                userFeedbackAnswer.ShowError(ble.Message);
            }           
        }



        public IQueryable<Category> ddl_Category_GetData()
        {
            return CategoryManager.List().AsQueryable();
        }

        public IQueryable<Question> gv_Questions_GetData()
        {
            return QuestionManager.ListByTest(test).AsQueryable();
        }

        public IQueryable<Answer> gv_Answers_GetData()
        {
            if (question.Exists())
            {
                List<Answer> answerList = AnswerManager.ListByQuestion(question);

                if (question.AnswersType.Value == AnswersType.FreeText && 
                    answerList.Count > 0 && 
                    SelectedAnswerNumber == null)
                {
                    this.answer = answerList[0];
                    this.SelectedAnswerNumber = this.answer.AnswerNumber;
                }
                return answerList.AsQueryable();
            }
            else
            {
                return new List<Answer>().AsQueryable();
            }
        }

        protected void btn_NewAnswer_Click(object sender, EventArgs e)
        {
            SelectedAnswerNumber = null;
            FillAnswerControls();
        }

       
        protected void gv_Answers_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                answer.Question = question;
                answer.AnswerNumber= TypeUtils.ToInt(this.gv_Answers.SelectedValue);
                if (answer.Load())
                {
                    FillAnswerControls();
                    SelectedAnswerNumber = answer.AnswerNumber;
                }
            }
            catch (BusinessLogicException ble)
            {
                userFeedbackAnswer.ShowWarning(ble.Message);
            }
            catch (Exception ble)
            {
                userFeedbackAnswer.ShowError(ble.Message);
            }           

        }

        private void FillQuestionControls()
        {
            if (question.Exists())
            {
                this.txt_QuestionDescription.Text = EncodingUtils.DecodeHtml(question.QuestionDescription);
                this.ddl_AnswersType.SelectedValue = question.AnswersType.ToValue();
                this.ddl_AnswersType.Enabled = false;
                this.ddl_Category.SelectedValue = question.Category.CategoryId.ToString();
            }
            else
            {
                this.txt_QuestionDescription.Text = "";
                this.ddl_AnswersType.SelectedIndex = -1;
                this.ddl_Category.SelectedIndex = -1;

            }
        }

        private void FillAnswerControls()
        {

            if (question.AnswersType.Value == AnswersType.FreeText)
            {
                if (answer.Exists())
                {
                    txt_FreeText_IsCorrectHint.Text = answer.IsCorrectHint;
                    txt_FreeText_IsIncorrectHint.Text = answer.IsIncorrectHint;
                    txt_CorrectValue.Text = answer.CorrectValue;
                }
                else
                {
                    txt_FreeText_IsCorrectHint.Text = "";
                    txt_FreeText_IsIncorrectHint.Text = "";
                    txt_CorrectValue.Text = "";

                }
            }
            else
            {
                if (answer.Exists())
                {
                    chk_IsCorrectAnswer.Checked = TypeUtils.ToBool(answer.CorrectValue);
                    txt_AnswerDescription.Text = answer.AnswerDescription;
                    txt_IsCorrectHint.Text = answer.IsCorrectHint;
                    txt_IsIncorrectHint.Text = answer.IsIncorrectHint;
                }
                else
                {
                    chk_IsCorrectAnswer.Checked = false;
                    txt_AnswerDescription.Text = "";
                    txt_IsCorrectHint.Text = "";
                    txt_IsIncorrectHint.Text = "";
                }
            }
        }


        protected void gv_Answers_RowCommand(object sender, GridViewCommandEventArgs e)
        {
            try                
            {
                this.answer.Question = this.question;
                this.answer.AnswerNumber = TypeUtils.ToInt(e.CommandArgument);
                if (answer.Load())
                {
                    FillAnswerControls();

                    SelectedAnswerNumber = answer.AnswerNumber;
                }
            }
            catch (BusinessLogicException ble)
            {
                userFeedbackAnswer.ShowWarning(ble.Message);
            }
            catch (Exception ble)
            {
                userFeedbackAnswer.ShowError(ble.Message);
            }           

        }

        protected string GetAnswerText(Answer answer)
        {
            string answerText = answer.AnswerDescription;
            if (answer.IsCorrect)
            {
                answerText+= " (resposta correcta)";
            }
            else 
            {
                answerText += " (resposta incorrecta)";
            }
            return answerText;
        }

        protected void BtnDeleteAnswer_Click(object sender, EventArgs e)
        {
            try
            {
                if (answer.Exists()) 
                {
                    answer.Delete();
                }               
            }
            catch (BusinessLogicException ble)
            {
                userFeedbackAnswer.ShowWarning(ble.Message);
            }
            catch (Exception ex)
            {
                userFeedbackAnswer.ShowError(ex.Message);
            }           

            this.gv_Answers.DataBind();

        }

        protected void BtnSaveMultimedia_Click(object sender, EventArgs e)
        {
            try
            {
                question.RemoveMultimedia(chk_RemoveImage.Checked, chk_RemoveSound.Checked);

                question.SaveMultimedia(fu_Image.FileName, fu_Image.FileContent, fu_Sound.FileName, fu_Sound.FileContent);

                DisplayMultimedia();

                pageTitle = question.ShortQuestionDescription;

                chk_RemoveImage.Checked= false;
                chk_RemoveSound.Checked = false;
            }
            catch (BusinessLogicException ble)
            {
                userFeedbackMultimedia.ShowWarning(ble.Message);
            }
            catch(Exception ex)
            {
                 userFeedbackMultimedia.ShowError(ex.Message);
            }
        }
        
        protected string GetTestUrl()
        {
            return string.Format("EditTest.aspx?TestId={0}&i=1", test.TestId.Value);
        }
    }

}