﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Enums;
using AutoProofreader.Exceptions;
using AutoProofreader.Managers;
using AutoProofreader.Utils;
using AutoProofreader.UI;

namespace Web.Teacher
{
    public partial class EditTest : EditPageBase
    {
        /// <summary>
        /// Security page check based on user type 
        /// </summary>
        protected override UserType pageUserType
        {
            get { return new UserType(UserType.Teacher); }
        }


        protected Test test;
        protected Question question;
        protected Answer answer;
        protected string pageTitle;

        protected long? SelectedTestId
        {
            get 
            {
                long? selectedTestId = TypeUtils.ToLong(Request.QueryString["TestId"]);
                if (!selectedTestId.HasValue)
                {
                    selectedTestId = TypeUtils.ToLong(ViewState["TestId"]);
                }
                return selectedTestId;
            }
            set
            {
                ViewState["TestId"] = value;
            }
        }


        protected override void InitData()
        {
            test = new Test();
            question = new Question();
            answer = new Answer();

            test.TestId = SelectedTestId;            

            if (Page.IsPostBack)
            {
                test.Load(false);
            }
        }

        protected override void LoadData()
        {
            test.Load();           
        }
 
        protected override void LoadControls()
        {
            FillTestControls();

            if (test.Exists())
            {
                btn_Preview.Visible = true;
                btn_Preview.OnClientClick = string.Format("javascript: previewTest({0}); return false;", test.TestId.Value);

                if (test.EditStatus.Value == EditStatus.Edit)
                {
                    this.btnSave.Visible = true;
                    this.btn_NewQuestion.Visible = true;
                    this.btn_Publish.Visible = true;
                    this.menu_Test.MenuItems[2].Visible = false;
                }
                else
                {
                    this.chk_isDeleted.Visible = false;
                    this.gv_TestQuestions.Columns[1].Visible = false;
                    this.btnSave.Visible = false;
                    this.btn_NewQuestion.Visible = false;
                    this.btn_Publish.Visible = false;
                    this.menu_Test.MenuItems[2].Visible = true;
                }
                chk_isDeleted.Visible = true;

                pageTitle = test.TestName;
            }
            else
            {
                pageTitle = "Nova prova";
                this.menu_Test.MenuItems[2].Visible = false;

                if (!Page.IsPostBack)
                {
                    menu_Test.ShowOnlyFirstMenuItem = true;
                }
                else
                {
                    menu_Test.ShowOnlyFirstMenuItem = false;
                }
                chk_isDeleted.Visible = false;
            }            
        }


        protected void BtnSaveTest_Click(object sender, EventArgs e)
        {
            try
            {
                bool exist = test.Exists();

                test.TestName = txt_TestName.Text;
                test.TestDescription = txt_TestDescription.Text;
                test.MaxAttempts = TypeUtils.ToInt(txt_MaxAttempts.Text);
                test.QuestionsPerPage = TypeUtils.ToInt(txt_QuestionsPerPage.Text);
                test.ResolutionMaxMinutes = TypeUtils.ToInt(txt_ResolutionMaxMinutes.Text);
                test.EvaluationType = EvaluationType.FromString(ddl_EvaluationType.SelectedValue);
                test.IsDeleted = chk_isDeleted.Checked;
                test.Save();

                //Update selected test
                SelectedTestId = test.TestId;

                //Reload controls
                LoadControls();

                //Show feedback
                this.userFeedback.ShowInfo("Prova guardada.");

                //Update header
                this.pnl_Header.Update();
            }
            catch (BusinessLogicException ble) 
            {
                userFeedback.ShowWarning(ble.Message);
            }
            catch (Exception ble)
            {
                userFeedback.ShowError(ble.Message);
            }             
        }

        public IQueryable<Category> ddl_Category_GetData()
        {
            return CategoryManager.ListInLibrary().AsQueryable();
        }

        public IQueryable<Question> gv_TestQuestions_GetData()
        {
            if (test.Exists())
            {
                return QuestionManager.ListByTest(test).AsQueryable();
            }
            else
            {
                return new List<Question>().AsQueryable();
            }            
        }

       
        public IQueryable<Classroom> ddl_Classroom_GetData()
        {
            return ClassroomManager.ListByNotAssignedToTest(test).AsQueryable();
        }

        public IQueryable<Classroom> gv_Classroom_GetData()
        {
            if (test.Exists())
            {
                return ClassroomManager.ListByTest(test).AsQueryable();
            }
            else
            {
                return new List<Classroom>().AsQueryable();
            }
        }
     

        private void FillTestControls()
        {
            if (test.Exists())
            {
                txt_TestName.Text = test.TestName;
                txt_TestDescription.Text = test.TestDescription;
                txt_MaxAttempts.Text = TypeUtils.ToString(test.MaxAttempts);
                txt_QuestionsPerPage.Text = TypeUtils.ToString(test.QuestionsPerPage);
                txt_ResolutionMaxMinutes.Text = TypeUtils.ToString(test.ResolutionMaxMinutes);
                ddl_EvaluationType.SelectedValue = test.EvaluationType.ToValue();
                chk_isDeleted.Checked = test.IsDeleted;                
            }
            else
            {
                txt_TestName.Text = "";
                txt_TestDescription.Text = "";
                txt_MaxAttempts.Text = "";
                txt_QuestionsPerPage.Text = "";
                txt_ResolutionMaxMinutes.Text = "";
                ddl_EvaluationType.SelectedIndex = 0;
                chk_isDeleted.Checked = false;
            }

        }

        protected void gv_TestQuestions_RowCommand(object sender, GridViewCommandEventArgs e)
        {            
            long? testQuestionId = TypeUtils.ToLong(e.CommandArgument);
            if (testQuestionId.HasValue)
            {
                if (e.CommandName == "remove")
                {
                    Question questionToRemove = new Question();
                    questionToRemove.TestQuestionId = testQuestionId;
                    test.UnassignQuestion(questionToRemove);
                }
                gv_TestQuestions.DataBind();
            }
        }

        protected void btn_NewQuestion_Click(object sender, EventArgs e)
        {
            this.pnl_AddQuestion.Visible = true;
            this.pnl_AddQuestion_Random.Visible = false;
            this.pnl_ListQuestions.Visible = false;

            this.ddl_QuestionType.SelectedIndex = 0;
        }

        protected void btn_SaveRandomQuestion_Click(object sender, EventArgs e)
        {
            //Add question to the test
            Category selectedCategory = new Category();
            selectedCategory.CategoryId = TypeUtils.ToLong(ddl_Category.SelectedValue);
            test.AssignQuestion(selectedCategory);

            //Refresh grid
            gv_TestQuestions.DataBind();

            //Reset form
            this.pnl_AddQuestion.Visible = false;
            this.pnl_AddQuestion_Random.Visible = false;
            this.pnl_ListQuestions.Visible = true;
        }


        protected void gv_TestQuestions_RowDataBound(object sender, GridViewRowEventArgs e)
        {
            if (e.Row.RowType == DataControlRowType.DataRow)
            {
                Question testQuestion = (Question)e.Row.DataItem;

                if (testQuestion.QuestionType.Value == QuestionType.Random)
                {
                    Literal literal = new Literal();
                    literal.Text = string.Format("Una pregunta aleatòria de la categoria {0}", testQuestion.Category.CategoryName);

                    e.Row.Cells[0].Controls.Add(literal);
                }
                if (testQuestion.QuestionType.Value == QuestionType.Library)
                {
                    HyperLink hl = new HyperLink();
                    hl.NavigateUrl = string.Format("EditQuestion.aspx?TestId={0}&QuestionId={1}", this.SelectedTestId, testQuestion.QuestionId);
                    hl.Text = EncodingUtils.CleanEncodedHtml(testQuestion.QuestionDescription);


                   e.Row.Cells[0].Controls.Add(hl);
                }
                if (testQuestion.QuestionType.Value == QuestionType.New)
                {
                    HyperLink hl = new HyperLink();
                    hl.NavigateUrl = string.Format("EditQuestion.aspx?TestId={0}&QuestionId={1}", this.SelectedTestId, testQuestion.QuestionId);
                    hl.Text = EncodingUtils.CleanEncodedHtml(testQuestion.QuestionDescription);

                    e.Row.Cells[0].Controls.Add(hl);
                }
            }
        }

        protected void btn_QuestionType_Click(object sender, EventArgs e)
        {
            QuestionType questionType = QuestionType.FromString(ddl_QuestionType.SelectedValue);
            if (questionType != null)
            {
                switch (questionType.Value)
                {
                    case QuestionType.Library:
                        RedirectTo(string.Format("QuestionList.aspx?TestId={0}&mode=add", test.TestId.Value));
                        break;
                    case QuestionType.New:
                        RedirectTo(string.Format("EditQuestion.aspx?TestId={0}", test.TestId.Value));
                        break;
                    case QuestionType.Random:
                        this.pnl_AddQuestion.Visible = false;
                        this.pnl_AddQuestion_Random.Visible = true;
                        break;
                }
            }
        }

        protected void btn_ShowPublish_Click(object sender, EventArgs e)
        {
            pnl_Classroom.Visible = false;
            pnl_AddClassroom.Visible = true;
        }

        protected void btn_PublishToClassroom_Click(object sender, EventArgs e)
        {
            DateTime startDate = txt_StartDate.GetDateTime().Value;
            DateTime endDate = txt_EndDate.GetDateTime().Value;
            Classroom classroom = new Classroom();
            classroom.ClassroomId = TypeUtils.ToLong(ddl_Classroom.SelectedValue);

            test.AddToClassroom(classroom, startDate, endDate);

            this.ddl_Classroom.DataBind();
            this.gv_Classroom.DataBind();

            pnl_Classroom.Visible = true;
            pnl_AddClassroom.Visible = false;

        }

        protected void btn_Publish_Click(object sender, EventArgs e)
        {
            try 
            {
                List<string> validationResult= test.Publish();
                if (validationResult.Count > 0)
                {
                    publishFeedback.ShowWarning("<b>NO s'ha pogut publicar la prova pels següents motius:</b><br/>", validationResult);
                }
                else
                {
                    publishFeedback.ShowInfo("La teva prova ha esta publicada i ara es trova a la biblioteca de preguntes. A partir d'ara, no es poden fer canvis a la prova.<br/>Pots publicar la teva prova a la pestanya 'Aules'.");
                }

            }
            catch (Exception ex)
            {
                publishFeedback.ShowError("<b>Error publicant la prova</b>: " + ex.Message);
            }
            LoadControls();

            this.gv_TestQuestions.DataBind();
            this.pnl_Header.Update();
        }

        protected void btn_Add_Question_Cancel_Click(object sender, EventArgs e)
        {
            this.pnl_AddQuestion.Visible = false;
            this.pnl_AddQuestion_Random.Visible = false;
            this.pnl_ListQuestions.Visible = true;

            this.gv_TestQuestions.DataBind();
        }

        protected void btn_PublishToClassroom_Cancel_Click(object sender, EventArgs e)
        {
            pnl_Classroom.Visible = true;
            pnl_AddClassroom.Visible = false;

            this.gv_Classroom.DataBind();
        }
    }

}
