﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using AutoProofreader.BusinessObjects;
using AutoProofreader.Enums;
using AutoProofreader.Exceptions;
using AutoProofreader.Managers;
using AutoProofreader.Utils;
using AutoProofreader.UI;

namespace Web.Teacher
{
    public partial class ViewClassroom : EditPageBase, IPostBackEventHandler 
    {
        protected Classroom classroom;
        protected string pageTitle;

        /// <summary>
        /// Security page check based on user type 
        /// </summary>
        protected override UserType pageUserType
        {
            get { return new UserType(UserType.Teacher); }
        }

        private long? SelectedClassroomId
        {
            get
            {
                long? SelectedClassroomId = TypeUtils.ToLong(Request.QueryString["ClassroomId"]);
                if (!SelectedClassroomId.HasValue)
                {
                    SelectedClassroomId = TypeUtils.ToLong(ViewState["SelectedClassroomId"]);
                }
                return SelectedClassroomId;
            }
            set
            {
                ViewState["SelectedClassroomId"] = value;
            }
        }

        private User selectedUser= null;


        protected override void OnInit(EventArgs e)
        {
            this.pnl_User.Visible = false;
            this.pnl_UserList.Visible = true;

            base.OnInit(e);
        }

        protected override void InitData()
        {
            this.classroom= new Classroom();
            this.classroom.ClassroomId = SelectedClassroomId;            
        }

        protected override void LoadData()
        {
            classroom.Load();
        }
        
        protected override void LoadControls()
        {
            gv_UserList.AllowPaging = false;
            gv_UserList.AllowSorting = false;

            FillClassroomControls();
        }

        /// <summary>
        /// CLick on view student
        /// </summary>
        /// <param name="eventArgument"></param>
        public void RaisePostBackEvent(string eventArgument)
        {
            long? userId = TypeUtils.ToLong(eventArgument);

            if (userId.HasValue)
            {
                selectedUser = new User();
                selectedUser.UserId = userId;
                if (selectedUser.Load())
                {
                    pnl_User.Visible = true;
                    pnl_UserList.Visible = false;

                    this.lb_FullName.Text = selectedUser.FullName;
                }
            }
        }

        public IQueryable<User> ddl_User_GetData()
        {
            if (classroom.Exists())
            {
                return UserManager.ListNotInClassroom(classroom).AsQueryable();
            }
            else
            {
                return null;
            }
        }

        protected void gv_User_RowDataBound(object sender, GridViewRowEventArgs e)
        {
            if (e.Row.RowType == DataControlRowType.DataRow)
            {
                User user = (User)e.Row.DataItem;

                if (user.UserType.Value == UserType.Student)
                {
                    HyperLink hl = new HyperLink();
                    hl.Text = user.ToString();
                    hl.NavigateUrl = "javascript: " + ClientScript.GetPostBackEventReference(this, user.UserId.ToString());

                    e.Row.Cells[1].Controls.Clear();
                    e.Row.Cells[1].Controls.Add(hl);
                }
            }
        }

        public IQueryable<User> gv_User_GetData()
        {
            if (classroom.Exists())
            {
                return UserManager.ListByClassroom(classroom).AsQueryable();
            }
            else
            {
                return null;
            }
        }

        public IQueryable<Attempt> gv_StudentAttempsList_GetData()
        {
            if (selectedUser.Exists() && classroom.Exists())
            {
                return AttemptManager.List(classroom, selectedUser).AsQueryable();
            }
            else
            {
                return null;
            }
        }

        private void FillClassroomControls()
        {
            if (classroom.Exists())
            {
                txt_ClassroomName.Text = classroom.ClassroomName;

                if (classroom.StartDate.HasValue)
                {
                    txt_StartDate.Text = classroom.StartDate.Value.ToShortDateString();
                }
                if (classroom.EndDate.HasValue)
                {
                    txt_EndDate.Text = classroom.EndDate.Value.ToShortDateString();
                }

                pageTitle = classroom.ClassroomName;
            }
            else
            {
                pageTitle = "Nova aula";
            }        
        }

        protected void btn_Back_Click(object sender, EventArgs e)
        {
            pnl_User.Visible = false;
            pnl_UserList.Visible = true;
            this.gv_UserList.DataBind();
        }
    }
}